function x0 = abtastdemo(fkt,fs,gt,gw)
% x0 = abtastdemo(fkt,fs,gt,gw)
% Demo fr die Zeitdiskretisierung eines kontinuierlichen Signals:
% fkt  : String, der die Funktion im Zeitbereich darstellt mit der 
%        Zeitvariablen t. Diese wird im Zeitbereich gt ausgewertet. 
% fs   : Abtastrate
% gt,gw: Grenzen fr den dargestellten Frequenzbereich.
% Beispiel:
% abtastdemo('exp(-t.^2).*(sin(2*pi*3*t)+0.6*sin(2*pi*5*t))',13,[-2,2],[-20,20]);

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<4  gw = [-20 20]; end
if nargin<3  gt = [-2 2]; end
if nargin<2  fs = 15; end
if nargin<1  fkt= 'exp(-t.^2).*(sin(2*pi*3*t)+0.6*sin(2*pi*5*t))'; end
fsiz = 12;                       % FontSize   

% Darstellung zeitkontinuierlich
% ==============================
h(1) = fullscreen(sprintf('Abtastung von  %s',fkt),'w',0,[3 1; 1 1]);
t = (0:799)/800*(gt(2)-gt(1))+gt(1); % "kontinuierlicher" Zeitbereich
line(t,zeros(size(t)));          % Zeitachse zeichnen
y = eval(fkt);                   % Funktion berechnen
line(t,y);                       % Funktion zeitkontinuierlich zeichnen

% Abtastung
% =========
ts= gt(1):1/fs:gt(2);            % Abtastpunkte
t = ts;                          % t auf Abtastpunkte umdefinieren (wegen eval)
ys= eval(fkt);                   % Funktion an Abtastpunkten berechnen
x = ys;                          % Rckgabe dieser Funktion: abgetastete Werte

% Darstellung zeitdiskret
% =======================
for i = 0:length(ts)-1
   line([ts(i+1),ts(i+1)],[0,ys(i+1)],'Color','r','LineWidth',1.5); 
end
fmark=line('Color','r','LineStyle','.','MarkerSize',10);
set(fmark,'xdata',ts,'ydata',ys);
str = sprintf('Abtastung von  %s',fkt);
title(str,'FontSize',fsiz)
xlabel('Zeitbereich','FontSize',fsiz)
set(gca,'xlim',gt)

% Hilfsgrssen
% ============
m  = 400;
du = 2*pi/(2*m+1);
k  = 1:length(y);
lt = gt(2)-gt(1);                % Lnge des Zeitbereichs
fb = (-m:m)/lt;                  % Frequenzbereich

% Fouriertransformation
% =====================
for u = -m:m  SR(u+m+1) = y*cos(u*du*k)'; end
for u = -m:m  SI(u+m+1) = y*sin(u*du*k)'; end
S = sqrt(SR.^2 + SI.^2);

% Darstellung des Spektrums des kontinuierlichen Signals
% ======================================================
h(2) = fullscreen('Spektrum des kontinuierlichen Signals','w',0,[3 1; 2 1]);
u = 0;
a = 1;
col = colormap;
c1= 30;
c2= 13;
ll= ceil(fs*lt+1);
while u+fs<m/lt
   xp = [u+(0:ll-1)/lt]+0.1;
   yp = S((round(lt*u):round(lt*(u+fs)))+m+1);
   yy(a,:) = [yp,zeros(1,ll-length(yp))];
   for z=1:ll 
      line([xp(z),xp(z)],[0,yy(a,z)],'Color',col(c1,:),'LineWidth',4)
      line([-xp(z),-xp(z)],[0,yy(a,z)],'Color',col(c2,:),'LineWidth',4)
   end
   cl(a,1) = c1;
   cl(a,2) = c2;
   u = u + fs;
   a = a + 1;
   c1 = rem(c1+47,61)+1;
   c2 = rem(c2+37,59)+1;
end
yl= get(gca,'ylim');
u = 0;
while u+fs<m/lt
   line([-u,-u],yl,'LineStyle',':','Color','r')
   line([u,u],yl,'LineStyle',':','Color','r')
   u = u + fs;
end
set(gca,'xlim',gw)
title('Spektrum des zeitkontinuierlichen Signals','FontSize',fsiz) 
xlabel('Frequenz [Hz]','FontSize',fsiz)

% Darstellung des Spektrums des abgetasteten Signals
% ==================================================
h(3) = fullscreen('Spektrum des abgetasteten Signals (eine Periode)','w',0,[3 1; 3 1]);
[zyy,syy] = size(yy);
x1 = (0:ll-1)/lt;
x2 = x1(ll:-1:1);
for a = 1:zyy
   line(x1,yy(a,:),'Color',col(cl(a,1),:),'LineWidth',2);
   line(x2,yy(a,:),'Color',col(cl(a,2),:),'LineWidth',2);
end
title('Spektrum des abgetasteten Signals (eine Periode)','FontSize',fsiz);
set(gca,'xlim',[0,fs])
figure(h(2)); figure(h(1)); 
set(h,'KeyPressFcn','zoom3d');
