function x = diskretifourier(S)
% x = diskretifourier(S)
% Bestimmung des zeitdiskreten Signals aus seiner periodischen
% Fouriertransformierten.
% Wird diskretifourier ohne Parameter aufgerufen, so wird 
% S mit diskretfourier mit dessen Default-Signal berechnet und 
% in diesem Fall zunchst Signal und Fouriertransformierte 
% abgebildet.
 
% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<1  S = diskretfourier; end;
fsiz = 12;                       % FontSize

% Hilfsgrssen
% ============
n  = 200;                        % Lnge des Zeitbereiches
m  = (length(S)-1)/2;            % Lnge der Frequenzperiode
u  = (-m:m)*2*pi/(2*m+1);        % eine Periode im Frequenzbereich
zb = 1:n;                        % Zeitbereich

% inverse Fouriertransformation
% =============================
for k=1:n  s(k) = S*exp(i*u*k)'; end
x = s;
s = real(s)/(2*m);

% Darstellung
% ===========
h = fullscreen('iFT','w',0,[1 1; 1 1]);
plot(zb,s)
line([zb;zb],[zeros(size(s));real(s)],'Color','r')
line(get(gca,'xlim'),[0 0],'LineStyle',':','Color','k')
fmark=line('Color','r','LineStyle','.','MarkerSize',10);
set(fmark,'xdata',zb,'ydata',s);
title('zeitdiskretes Signal s nach inverser Fouriertransformation','FontSize',fsiz) 
xlabel('Zeitbereich','FontSize',fsiz)

