function h = drawarr(von,nach,farbe,lw,spl,re,rs)
%  h = drawarr(von,nach,farbe,lw,spl,re,rs)
%  Zeichnet einen Pfeil der farbe und Strke lw sowie
%  der Spitzenlnge spl zwischen den Koordinaten von und nach.
%  Die Lnge des Pfeils lsst sich am Schaft bzw. an der Spitze
%  um re bzw. rs krzen. nach kann deshalb der Mittelpukt eines
%  Kreises sein und rs dessen Radius. 
%  Die Spitzenlnge bezieht sich auf die Lnge des Einheitsvektors
%  in Pfeilrichtung bei den gegebenen Achsen.
%  Zurckgegeben werden die Handles der Linie und Spitze.
%  Die Achsen sollten vor dem Aufruf von drawarr festgelegt werden.

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<7  rs  = 0; end
if nargin<6  re  = 0; end
if nargin<5  spl = 3; end
if nargin<4  lw  = 2; end
if nargin<3  farbe = 'k'; end

% Konstanten
% ==========
a = spl; b = spl/3;
pos = get(gcf,'Position');
xl = get(gca,'XLim');
yl = get(gca,'YLim');
xs = (xl(2)-xl(1))/pos(3);
ys = (yl(2)-yl(1))/pos(4);
q  = xs/ys;
u  = nach - von;
lu = norm(u);
u  = u/lu;  ux = u(1);  uy = u(2);
vx = u(2)*q;  vy = u(1)/q;
shft = von + re*u;
spze = nach - rs*u;
nx = spze(1); ny = spze(2);

% Pfeil
% =====
h  = [line([shft(1),spze(1)],[shft(2),spze(2)],'Color',farbe,'LineWidth',lw),...
      patch([nx,nx-a*ux+b*vx,nx-a*ux-b*vx],...
            [ny,ny-a*uy-b*vy,ny-a*uy+b*vy],farbe)];

