function z = dsbmod(f0,x,f1)
% dsbmod(f0,x,f1)
% Demonstriert die Zweiseitenmodulation ohne Trger.
% Ausgegeben wird das modulierte Signal. 
% Wird die Ausgabe einer Variablen zugewiesen, so unterbleibt 
% die grafische Darstellung.
% Es wird ein Zeitabschnitt von t = 0...1 gezeigt.
% f0 ist die Trgerfrequenz. Fr die Demonstration ist f0 = 50 gut.
% x ist ein String, der das Signal als Funktion in MATLAB-Syntax mit 
% der Zeitvariablen t angibt. Alternativ kann ein Vektor angegeben 
% werden.
% f1 ist der zur Demodulation verwendete Trger. Default: f1 = f0.
% Gezeigt wird:
% Oberes Bild:     das zu modulierende Signal
% Mittleres Bild:  das modulierte Signal
% Unteres Bild:    das demodulierte Signal
% Beispiel:  dsbmod(40,'0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)')

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<2 x = '0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)'; end
if nargin<1 f0 = 40; end                      % Default fr Trger
if nargin<3 f1 = f0; end                      % Default fr Demodulatortrger
hlcol = 0.7*[1 1 1];
patchcol = 0.8*[1 1 1];
fsiz  = 14;
g = 30;                                       % Filtergrad fr Hilbertfilter
mm= 3;
m = g/2+mm;                                   % Einschwingbereich
if ischar(x) n = 512; else n = length(x); end
%
% Signalerzeugung
% ===============
t = (0:n-1)/n;                                % Zeitsegment
if ischar(x) s = eval(x); else s = x; end     % Signal
z = s.*cos(2*pi*f0*t);                        % Modulation
%
if nargout>0 break; end
%
% Demodulation
% ============
w = z + cos(2*pi*f1*t);                       % Trgerzusatz
y = real2analyt(w,g);                         % analytisches AM-Signal
a = abs(y)-1;                                 % Demodulation
%
% Wegschneiden des Einschwingbereiches
% ====================================
n = length(t);
t = t(mm+1:n-m+1); s = s(mm+1:n-m+1); z = z(mm+1:n-m+1); a = a(m:n-mm);
%
if nargout>0  break; end
%
% Darstellung
% ===========
d  = 0.05;
fh = fullscreen('DSB ohne Trger');
axes('Position',[0  2/3  1  1/3-d])
plot(t,s); line([0 1],[0 0],'LineStyle',':','Color',hlcol);
set(gca,'XLim',[0.01,0.96]); axis off
title(x,'FontSize',fsiz)
axes('Position',[0  1/3  1  1/3-d])
patch([t,reverse(t)],[s,-reverse(s)],patchcol,'EdgeColor','w'); 
line(t,z)
set(gca,'XLim',[0.01,0.96]); axis off
title('Zweiseitenbandmodulation ohne Trger','FontSize',fsiz)
axes('Position',[0  0  1  1/3-d])
plot(t,a); line([0 1],[0 0],'LineStyle',':','Color',hlcol);
set(gca,'XLim',[0.01,0.96]); axis off
title('demoduliertes Signal','FontSize',fsiz)
