function y = faltcode(x,g,m,q)
% y = faltcode(x,g,m,q)
% Der Informationsvektor x wird mit dem durch die Matrix g der 
% Generator-Polynome definierten Faltungscode im GF(q) kodiert.
%
% x  :      Vektor der Symbole aus GF(q) {0 ... q-1}
%
% g  :      Matrix der Faltungspolynome  {0 ... q-1}
%
% m ~= 1 :  Fr jede Zeile von g wird eine Zeile von y generiert.
% m = 1  :  Alle Faltungsergebnisse verzahnt zu einem Bitstrom.
%           Default : m = 0 .
%
% q  :      Anzahl der Elemente des endlichen Krpers.
%           q muss Primzahlpotenz sein.
%           Falls q prim ist, wird Restklassenarithmetik benutzt,
%           andernfalls werden einmalig mit Polynomarithmetik die 
%           Tabellen fr Addition und Multiplikation erzeugt, die 
%           von spteren Aufrufen von faltcode mit dem selben q 
%           wiederverwendet werden.
%
% Hinweise: faltcode verndert bzw. benutzt die globale Variable FALTCODE_GF.
%
%           Aufgrund einer Instabilitt in der benutzten Funktion  gf_new 
%           gibt es fr folgende Werte von q bisweilen Probleme:
%           25,  49,  81,  121, 125

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

global FALTCODE_GF

if nargin<4  q = 2; end
if nargin<3  m = 0; end
fq = factor(q); 
if q~=fq(1)^length(fq) error('faltcode: q muss Primzahlpotenz sein'); end
[r,k] = size(g);      % Constraint-Lnge k, Rate 1/r

if length(fq)==1
   for i=1:r  y(i,:) = rem(conv(x,g(i,:)),q); end;
else
   try,   qq = FALTCODE_GF.q;
          if qq~=q error(0); end    % knstlicher Fehler
   catch, FALTCODE_GF = gftab(q);
   end
   for i=1:r  y(i,:) = convgf(x+1,g(i,:)+1,FALTCODE_GF)-1; end
end

if m==1  y = flach(y'); end
