function x0 = faltcodesim(ir,k,n,ebnodb)
% x0 = faltcodesim(ir,k,n,ebnodb)
% Simulation der Faltungscodierung und Dekodierung.
% ir :  inverse Koderate
% k  :  Constraint Length
% n  :  Anzahl der Informationsbits (random)
% ebnodb:  Eb/No in dB
% Ausgegeben wird die Anzahl der Bitfehler in der dekodierten Sequenz.
% Falls die Ausgabe auf eine Variable zugewiesen wird, gibt es keine Grafik.

% Autor:  Klaus von der Heide,  v.d.heide@on-line.de

if nargin<1  ir= 3; end           % inverse Koderate
if nargin<2  k = 5; end           % Constraint Length
if nargin<3  n = 100; end         % Anzahl der Informationsbits
if nargin<4  ebnodb = 2.0; end    % Eb/No in dB
lw= 2;                            % LineWidth
g = faltpoly(ir,k);               % Kodierungspolynome 
x = randb(n);                     % zufllige Information
c = faltcode(x,g,1);              % Kodierung
y = add_awgn(2*c-1, 1/ir,ebnodb); % Kanalrauschen
z = viterbi(g,y);                 % Dekodierung
x0= sum(z~=x);                    % Anzahl der Bitfehler
if nargout>0  break; end          % falls Ausgabe dann kein Bild
h = fullscreen('Faltungscode');
axes('Position',[0.2 0.55 0.6 0.5]);
hist(y,-4.9:0.2:+4.9)             % Histogramm des Empfangssignals
set(gca,'xlim',[-5 +5],'Visible','off')
axes('Position',[0.02 0.05 0.96 0.5])
line(1:length(c),2*c-1,'Color','r','LineWidth',lw) % Sendesignal
line(1:length(c),y,'Color','b','LineWidth',lw)     % Empfangssignal
line([1,length(c)],[0 0],'Color',0.7*[1 1 1])      % Nulllinie
axis([1 length(c) -4 +4]), axis off

