function [x0,y0] = fktabtast(tmax,fs,fkt,bits)
% [x0,y0] = fktabtast(tmax,fs,fkt,bits)
% Abtastung der als String fkt anzugebenden Funktion 
% im Zeitbereich  t = 0..tmax  mit der Abtastrate fs.
% Die freie Zeitvariable in der Funktion ist dabei t.
% Falls mit bits die Anzahl der Bits fr die Reprsentation 
% im 2-Komplement angegeben wird, erfolgt die Abtastung 
% im Wertebereich -1 ... +1. Die Funktion ist dann also auf 
% diesen Bereich zu skalieren.
% fktabtast gibt im Vektor x0 die abgetasteten Werte und 
% im Vektor y0 die Abtastfehler zurck.
% Beispiele: fktabtast(2,20,'0.7*(cos(2*pi*1.3*t).^2+0.8*sin(2*pi*1.9*t))',4);
%            fktabtast(5,10,'0.2*(cos(2*pi*0.7*t)+0.8*sin(2*pi*0.9*t))',4);
%            fktabtast(3,20,'2*t.^2.*sin(2*pi*1.3*t).*exp(-t.^2)',5);

% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<4  bits = 24; end
if nargin<3  fkt  = '2*t.^2.*sin(2*pi*1.3*t).*exp(-t.^2)'; end;
if nargin<2  fs   = 20; end;
if nargin<1  tmax =  3; end;
fsiz = 13;                       % FontSize

% Abtastung
% =========
n = floor(tmax*fs);              % Anzahl der Abtastungen im Zeitbereich
ts= (0:n)/fs;                    % quidistante Abtastpunkte
t = ts;                          % t auf Abtastpunkte umdefinieren (wegen eval)
ya= eval(fkt);                   % Funktion an Abtastpunkten berechnen
if length(ya)~=length(t)  
   error('Funktion liefert falsche Zahl von Abtastwerten (max, min, sum, prod etc. benutzt?)')
end
ys= ya;
if nargin>3                      % falls bits angegeben, dann digitalisieren 
   ys = min(1-2^(1-bits),ys);    % bei +1 abschneiden
   ys = max(-1,ys);              % bei -1 abschneiden
   ys = round(ys*2^(bits-1))*2^(1-bits); % digitalisieren im 2-Komplement
end
x0 = ys;                         % Rckgabe: abgetastete Werte
y0 = ys - ya;                    % Rckgabe: Abtastfehler

if nargout>0  break; end
   
% Bilderzeugung
% =============
h = fullscreen(sprintf('Abtastung von  %s',fkt));

% Darstellung der Abtastniveaus
% =============================
if bits<9
   for k=-2^(bits-1):(2^(bits-1)-1)  
      line(tmax*[0 1],k*2^(1-bits)*[1 1],'Color',0.8*[1 1 1]); 
   end
end

% Darstellung zeitkontinuierlich
% ==============================
t = tmax*(0:799)/800;            % "kontinuierlicher" Zeitbereich: 800 Punkte
line(t,zeros(size(t)));          % Zeitachse zeichnen
y = eval(fkt);                   % Funktion berechnen
line(t,y,'LineWidth',2.0);       % Funktion zeitkontinuierlich zeichnen

% Darstellung zeitdiskret
% =======================
for i = 0:n  line([ts(i+1),ts(i+1)],[0,ys(i+1)],'Color','r','LineWidth',2.5); end
line(ts,ys,'Marker','o','Color','r','LineStyle','none','LineWidth',3,'MarkerSize',5);
str = sprintf('Abtastung von   %s',deletepoint(fkt));
if nargin>3  str = sprintf('%s   und Digitalisierung in %3.0f Bits',str,bits); end
title(str,'FontSize',fsiz)
xlabel('Zeitbereich','FontSize',fsiz)
if nargin>3  axis([0 tmax -1 +1]); end
