function symfour = fourierplot(symfkt,argfkt,argfour,tlim,wlim)
% symfour = fourierplot(symfkt,argfkt,argfour,tlim,wlim)
% Plot einer komplexen Funktion und ihrer Fouriertransformierten.
% symfkt :  Symbolischer Funktionsausdruck.
% argfkt :  Die symbolische Variable der Funktion symfkt.
% argfour:  Die symbolische Variable der Fouriertransformierten (Kreisfrequenz)
% tlim   :  Vektor der Lnge 2, der die Darstellungsgrenzen von argfkt enthlt.
% wlim   :  Vektor der Lnge 2, der die Darstellungsgrenzen von argfour enthlt.
%           tlim und wlim sind die Grenzen, in denen der Plot zunchst 
%           erscheint. Beide Plots knnen anschliessend mit der Maus gedreht 
%           und mit den in zoom3d erluterten Tasten verndert werden.
%           Ist die Funktion reell, so wird nur diese Projektion gezeigt, 
%           andernfalls eine Schrgprojektion.
% symfour:  Symbolischer Ausdruck der Fouriertransformierten.
%
% Die symbolischen Variablen argfkt und argfour mssen vor Aufruf 
% dieser Funktion als symbolische Variable erklrt werden.
% Beispiel: syms x w; fourierplot(exp(-x^2)*(cos(x)+sin(2*x)),x,w)
%
% Hinweise: Die symbolische Berechnung gelingt bei vielen Funktionen nicht.
% Dann gibt es die Fehlermeldung: No appropriate methods for function fourier 
% oder auch andere weniger spezifische Fehlermeldungen.
% Bisweilen hilft das Unterbinden der Auswertung von symfkt bei der 
% Parameterbergabe durch Einklammerung von symfkt in Stringquotes. 
% Dann mssen allerdings alle Konstanten als Werte im String stehen. 

% Autor:  Klaus von der Heide, e-mail:  v.d.heide@om-line.de

% Konstanten und Defaults
% =======================
if nargin<5     wlim = [-50,+50];  end
if nargin<4     tlim = [-1,+1];    end
if nargin<3  argfour = 'w';        end
if nargin<2   argfkt = 't';        end

n = 2048;                      % Anzahl der Punkte der Darstellung

% Symbolische Fouriertransformation
% =================================
p = symfkt;                    % Definition der Funktion als symbolisch
P = fourier(p,argfkt,argfour); % die Fouriertransformierte von p,
symfour = simple(P);           % Ausgabe

% Darstellung: Zeitbereich
% ========================
fh1 = fullscreen('Funktion','w',1,[1 2; 1 1]);
set(fh1,'KeyPressFcn','zoom3d');
argt = tlim(1):(tlim(2)-tlim(1))/n:tlim(2);
fss  = strrep(char(symfkt),'Dirac','diracpuls');     
for k=1:length(argt) 
   eval([char(argfkt),' = argt(k);']);
   fcn(k) = eval(fss);
end
mxr = max(real(fcn));
mnr = min(real(fcn));
mxi = max(imag(fcn));
mni = min(imag(fcn));
plot3(argt,real(fcn),imag(fcn))
line(tlim,[0 0],[0 0],'LineStyle',':')
line([0 0],[mnr mxr],[0 0],'LineStyle',':')
line([0 0],[0 0],[mni mxi],'LineStyle',':')
xlabel(char(argfkt))
ylabel('Realteil')
zlabel('Imaginrteil')
title(char(symfkt))
set(gca,'XLim',tlim,'UserData',1)
if max([abs(mxi),abs(mni)])<0.05*max([abs(mxr),abs(mnr)]) 
   set(gca,'view',[0,90]); 
end
axis square
rotate3d

% Darstellung: Frequenzbereich
% ============================
fh2 = fullscreen('Fouriertransformierte','w',1,[1 2; 1 2]);
set(fh2,'KeyPressFcn','zoom3d');
argf = wlim(1):(wlim(2)-wlim(1))/n:wlim(2);
ps = strrep(char(P),'Dirac','diracpuls');     
for k=1:length(argf) 
   eval([char(argfour),' = argf(k);']);
   four(k) = eval(ps);
end
mxr = max(real(four));
mnr = min(real(four));
mxi = max(imag(four));
mni = min(imag(four));
if abs(mxi)+abs(mni)<1.0e-6*(abs(mxr)+abs(mnr))  mxi = 1; mni = -1; end
plot3(argf,real(four),imag(four))
line(wlim,[0 0],[0 0],'LineStyle',':')
line([0 0],[mnr mxr],[0 0],'LineStyle',':')
line([0 0],[0 0],[mni mxi],'LineStyle',':')
xlabel(char(argfour))
ylabel('Realteil')
zlabel('Imaginrteil')
title(char(symfour))
set(gca,'XLim',wlim,'UserData',1)
axis square
rotate3d
