function z = freqmod(f0,x,hub,f1,hubd)
% z = freqmod(f0,x,hub,f1)
% Demonstriert die Frequenzmodulation.
% Ausgegeben wird das modulierte Signal. Wird die Ausgabe auf 
% eine Variable zugewiesen, so unterbleibt die grafische Darstellung.
% Es wird ein Zeitabschnitt von t = 0...1 gezeigt.
% f0 ist die Trgerfrequenz. Fr die Demonstration ist f0 = 50 gut.
% x ist ein String, der das Signal als Funktion in MATLAB-Syntax mit 
% der Zeitvariablen t angibt. Alternativ kann ein Vektor angegeben 
% werden.
% hub ist der Frequenzversatz fr x = 1
% f1 ist die beim Empfnger angenommene Trgerfrequenz
% hubd ist der beim Empfnger angenommene Hub
% Defaults:  f1 = f0,  hubd = hub;
% Beispiel:  freqmod(50,'0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',0.05)
%
% Defaults
% ========
if nargin<3  hub = 0.05;end
if nargin<2    x = '0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)'; end
if nargin<1   f0 = 50;  end
if nargin<4   f1 = f0;  end                   % Default fr Demodulatortrger
if nargin<5 hubd = hub; end                   % Default fr Demodulatortrger
fsiz  = 14;
hlcol = 0.7*[1 1 1];
patchcol = 0.8*[1 1 1];
if ischar(x) n = 512; else n = length(x); end
g = 30;                                       % Filtergrad fr Tiefpassfilter
mm= ceil(g/2);
m = 2*mm;                                     % Einschwingbereich
%
% Signalerzeugung
% ===============
t = (0:n+m-1)/n;                              % Zeitsegment
if ischar(x) s = eval(x); else s = [x,zeros(1,m)]; end % Signal
si(1) = s(1);
for k=2:length(t) si(k) = si(k-1) + s(k); end
z = cos(2*pi*(f0.*t+hub*si));                 % Modulation
%
if nargout>0  break; end
%
% Demodulation nach Kammeyer
% ==========================
tr = exp(i*2*pi*f1*t);                        % Trger im Demodulator
y  = z.*tr;                                   % Transformation ins Basisband
b  = fir1(g,0.05);                            % Entwurf des Tiefpassfilters
x  = filter(b,1,y);                           % Tiefpass zur Sperrung von 2*f1
w  = x./abs(x);                               % Beseitigung der Amplitudenschwankung
wt = [0 w(1:length(w)-1)];                    % Verzgerung um 1 Abtastschritt
a  = -asin(imag(w.*conj(wt)))/(2*pi*hubd);    % Demodulation
%
% Wegschneiden des Einschwingbereiches
% ====================================
n = length(t);
t = t(1:n-m+1); s = s(1:n-m+1); z = z(1:n-m+1); a = a(mm:n+mm-m);
%
% Darstellung
% ===========
d  = 0.05;
fh = fullscreen('Frequenzmodulation');
axes('Position',[0  2/3  1  1/3-d])
plot(t,s); line([0 1],[0 0],'LineStyle',':','Color',hlcol);
set(gca,'XLim',[0.01,0.99]); axis off
yl = get(gca,'YLim');
if ischar(x) title(x,'FontSize',fsiz); else title('Signal','FontSize',fsiz); end
axes('Position',[0  1/3  1  1/3-d])
patch([t,reverse(t)],[ones(1,length(t)),-ones(1,length(t))],patchcol,'EdgeColor','w')
line(t,z)
set(gca,'XLim',[0.01,0.99]); axis off
title('Frequenzmodulation','FontSize',fsiz)
axes('Position',[0  0  1  1/3-d])
plot(t,a); line([0 1],[0 0],'LineStyle',':','Color',hlcol);
title('demoduliertes Signal','FontSize',fsiz)
set(gca,'XLim',[0.01,0.99]); axis off
ylm = get(gca,'YLim');
if sum(ylm)>0.1*diff(ylm)  set(gca,'YLim',yl-yl(1)+min(a)); end
