function z = fsktx(symbole,f0,baud,hub,vor)
% z = fsktx(symbole,f0,baud,hub,vor)
% FSK-Sender
% symbole:  Vektor der zu sendenden Symbole aus {-1 +1}.
% f0     :  Trgerfrequenz relativ zur Abtastfrequenz
% baud   :  Baudrate bezogen auf die Abtastfrequenz
% hub    :  Frequenzhub fr Symbol = 1.0 bezogen auf die Abtastfrequenz
% vor    :  Anzahl der Einsen vorweg
% Die Symbole werden mit Raised Cosine verbunden.
% Die Defaultwerte gelten fr V.21 bei der Abtastung mit 8 kHz.

% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de
%
% Defaults und Konstanten
% =======================
if nargin<5  vor = 0;      end
if nargin<4  hub = 0.0125; end
if nargin<3 baud = 0.0375; end
if nargin<2   f0 = 0.135;  end
if nargin<1 symbole = 1-2*randb(8); end
schritt = round(1/baud);
n = length(symbole);
if rem(n,8) error('fsktx: die Lnge von symbole muss 8*m sein'); end
m = n/8;

% Bitsequenz
% ==========
lv = round(5*rand) + 6;
sequenz = ones(1,vor + lv);                 % Vorlauf
for k=0:m-1
   sequenz = [sequenz -1 symbole(8*k+1:8*k+8) 1 1]; % Startbit, Byte, 2 Stoppbits
end
sequenz = [sequenz ones(1,vor+14-lv)];      % Auslauf

% Signalerzeugung
% ===============
basband  = raisedcosine(sequenz,schritt);
t = 0:length(basband) - 1;                  % Zeitsegment
z = cos(2*pi*(f0*t + hub*cumsum(basband))); % Modulation