function figh = fullscreen(name,col,mb,fp)
% figh = fullscreen(name,col,mb,fp)
% name  :  String fr FigureName
% col   :  Farbe der Umrahmung
% mb    :  Sichtbarkeit und Anzeige von Kopfzeile und MenuBar:
% mb = 0   keine MenuBar, Kopfzeile darf verdeckt werden
% mb = 1   keine MenuBar, Kopfzeile wird nicht verdeckt
% mb = 2   MenuBar und Kopfzeile drfen verdeckt werden
% mb = 3   MenuBar und Kopfzeile werden nicht verdeckt
% fp    :  Position des Fensters auf dem Bildschirm:
% fp = [n,m;i,j] :  der Bildschirm wird in eine n*m-Matrix 
%                   gleich grosser Bilder zerlegt. i,j sind 
%                   die Indices des gewhlten Bildes.
%                   n,m,i,j drfen reelle Zahlen sein (z.B. [2, 3; 1.5, 2.5])
% fp = [l,r,u,o] :  Grenzen links, rechts, unten, oben in 
%                   Einheiten des Bildschirms (Breite = 1, Hhe = 1)
%
% Falls die Zuweisung auf figh erfolgt, wird das Bild mit handle figh erzeugt
% und folgende Eigenschaften gesetzt:
% set(figh,'Name',name,'Color',col,'MenuBar','none','NumberTitle','off','Position',pos)
% set(figh,'KeyPressFcn','zoom3d')
% Wird figh nicht zugewiesen, so werden die Eigenschaften von gcf entsprechend gesetzt
% ausser KeypressFcn.
%
% Beispiel:
% n = 7;
% for u = n:-1:1  
%    for v = 1:u  
%        fh(u*(u-1)/2+v) = fullscreen(sprintf('Bild  %d / %d',u,v),[u/n,v/n,0],0,[n u; u v]); 
%    end
% end

if nargin<4   fp = [1 1; 1 1]; end
if nargin<3   mb = 0;          end
if nargin<2  col = 'w';        end
if nargin<1 name = 'no name';  end
ss = get(0,'ScreenSize');

[u,v] = size(fp);
bl = 0.003;
bb = 1 - 2*bl;
switch mb
   case 0,
      bu = 0.046;
      bh = 0.93;
      hf = 0.99;
   case 1,
      bu = 0.046;
      bh = 0.96;
      if u==2  hf = 1 - 0.035*fp(1,1); else hf = 1; end
   case 2,
      bu = 0.046;
      bh = 0.868;
      hf = 1;
   case 3,
      bu = 0.046;
      bh = 0.96;
      if u==2  hf = 1 - 0.1*fp(1,1); else hf = 1; end
end 
if u==1 & v==4
   pos = round([(bl+bb*fp(1))*ss(3),...
                (bu+bh*fp(3))*ss(4),...
                 bb*(fp(2)-fp(1))*ss(3),...
                 bh*(fp(4)-fp(3))*ss(4)]);
else if u==2 & v==2
      pos = round([(bl+bb/fp(1,2)*(fp(2,2)-1))*ss(3),...
                   (bu+bh/fp(1,1)*(fp(1,1)-fp(2,1)))*ss(4),...
                    bb/fp(1,2)*ss(3),...
                    bh*hf/fp(1,1)*ss(4)]);    
     end
end

if nargout>0 
   figh = figure; 
   set(figh,'KeyPressFcn','zoom3d')
else 
   figh = gcf; 
end
set(figh,'Name',name,'Color',col,'NumberTitle','off','Position',pos)
if mb<2 set(figh,'MenuBar','none'); end