function symfkt = ifourierplot(symfour,argfour,argfkt,wlim,tlim)
% symfkt = ifourierplot(symfour,argfour,argfkt,wlim,tlim)
% Plot einer komplexen Fouriertransformierten und der Rcktransformierten.
% symfour:  symbolischer Funktionsausdruck.
% argfour:  Die symbolische Variable der Fouriertransformierten.
% argfkt :  Die symbolische Variable der Funktion symfkt.
% wlim   :  Vektor der Lnge 2, der die Darstellungsgrenzen von argfour enthlt.
% tlim   :  Vektor der Lnge 2, der die Darstellungsgrenzen von argfkt enthlt.
%           tlim und flim sind die Grenzen, in denen der Plot zunchst 
%           erscheint. Beide Plots knnen anschliessend mit der Maus gedreht 
%           und mit den in zoom3d erluterten Tasten verndert werden.
%           Ist die Funktion reell, so wird nur diese Projektion gezeigt, 
%           andernfalls eine Schrgprojektion.
% symfkt:   Symbolischer Ausdruck der inversen Fouriertransformierten.
%
% Die symbolischen Variablen argfkt und argfour mssen vor Aufruf 
% dieser Funktion als symbolische Variable erklrt werden.
% Beispiel: syms x w; ifourierplot(exp(-w^2)*(cos(w)+sin(2*w)),w,x,[-3,3],[-20 20])
%
% Hinweis:  Die symbolische Berechnung gelingt bei vielen Funktionen nicht.
% Dann gibt es die Fehlermeldung: No appropriate methods for function fourier 
% oder auch andere weniger spezifische Fehlermeldungen.
% Bisweilen hilft das Unterbinden der Auswertung von symfour bei der 
% Parameterbergabe durch Einklammerung von symfour in Stringquotes. 
% Dann mssen allerdings alle Konstanten als Werte im String stehen. 

% Autor:  Klaus von der Heide, e-mail:  v.d.heide@om-line.de

% Konstanten und Defaults
% =======================
if nargin<5     tlim = [-1,+1];   end
if nargin<4     wlim = [-50,+50]; end
if nargin<3   argfkt = 't';       end
if nargin<2  argfour = 'w';       end

n = 1024;                       % Anzahl der Punkte der Darstellung

% Symbolische Fouriertransformation
% =================================
P = symfour;                    % Definition der Funktion als symbolisch
p = ifourier(P,argfour,argfkt); % die Fouriertransformierte von p,
symfkt = simple(p);             % Ausgabe

% Darstellung: Zeitbereich
% ========================
fh1 = fullscreen('Funktion','w',1,[1 2; 1 1]);
set(fh1,'KeyPressFcn','zoom3d');
argt = tlim(1):(tlim(2)-tlim(1))/n:tlim(2);
fss  = strrep(char(symfkt),'Dirac','diracpuls');     
for k=1:length(argt) 
   eval([char(argfkt),' = argt(k);']);
   fcn(k) = eval(fss);
end
mxr = max(real(fcn));
mnr = min(real(fcn));
mxi = max(imag(fcn));
mni = min(imag(fcn));
plot3(argt,real(fcn),imag(fcn))
line(tlim,[0 0],[0 0],'LineStyle',':')
line([0 0],[mnr mxr],[0 0],'LineStyle',':')
line([0 0],[0 0],[mni mxi],'LineStyle',':')
xlabel(char(argfkt))
ylabel('Realteil')
zlabel('Imaginrteil')
title(char(symfkt))
set(gca,'XLim',tlim,'UserData',1)
if max([abs(mxi),abs(mni)])<0.05*max([abs(mxr),abs(mnr)]) 
   set(gca,'view',[0,90]); 
end
axis square
rotate3d
set(fh1,'KeyPressFcn','zoom3d')

% Darstellung: Frequenzbereich
% ============================
fh2 = fullscreen('Fouriertransformierte','w',1,[1 2; 1 2]);
set(fh2,'KeyPressFcn','zoom3d');
argf = wlim(1):(wlim(2)-wlim(1))/n:wlim(2);
ps = strrep(char(P),'Dirac','diracpuls');     
for k=1:length(argf) 
   eval([char(argfour),' = argf(k);']);
   four(k) = eval(ps);
end
mxr = max(real(four));
mnr = min(real(four));
mxi = max(imag(four));
mni = min(imag(four));
plot3(argf,real(four),imag(four))
line(wlim,[0 0],[0 0],'LineStyle',':')
line([0 0],[mnr mxr],[0 0],'LineStyle',':')
line([0 0],[0 0],[mni mxi],'LineStyle',':')
xlabel(char(argfour))
ylabel('Realteil')
zlabel('Imaginrteil')
title(char(symfour))
set(gca,'XLim',wlim,'UserData',1)
axis square
rotate3d
set(fh2,'KeyPressFcn','zoom3d')
