function y = impulsfolge(symb,impuls,schritt,sp,L)
% y = impulsfolge(symb,impuls,schritt,sp,L)
% Erzeugung und Darstellung eines Sendesignals fr die 
% Symbole symb mit dem Sendeimpuls impuls und der 
% Schrittweite schritt. 
% L ist der Partial-Response-Faktor (Default: L = 1 fr full response)
% Die Darstellung unterbleibt, wenn die Ausgabe auf eine Variable zugewiesen wird.
% Mit sp~=0 kann zustzlich die Darstellung des Spektrums angefordert werden.

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<5        L = 1;  end
if nargin<4       sp = 0;  end
if nargin<3  schritt = 20; end
if nargin<2   impuls = 'Sinc'; end
if nargin<1     symb = randx(16,-1:0.666:+1); end
ms = min(symb);
ns = 10;
br = 3;                       % Breite der Spektraldarstellung in Schrittfrequenz
fsiz = 13;
sc = L*schritt;               % Pseudoschrittlnge

% Impulsform
% ==========
if ischar(impuls)
   switch impuls
      case {'RC','rc'},       puls = (1 + cos(pi*(-sc:sc)/sc))/2;
      case {'Gauss','gauss'}, puls = exp(-(pi*(-3*sc:3*sc)/sc/2).^2);
      case {'PR4','pr4'},
         t    = (-6*schritt:+6*schritt)/schritt;
         in0  = schritt*[5 7] + 1;
         t(in0) = 0;
         puls = 2*sin(pi*t)./(pi*(t.^2-1));
         puls(in0(1)) = +1;
         puls(in0(2)) = -1;
      case {'Rect','rect'},   puls = rectpuls(-sc/2:sc/2,sc);
      case {'Sinc','sinc'},   puls = rcsinc((-10*sc:10*sc)/sc,10*sc);
      case {'Tri','tri'},     puls = tripuls(-sc:sc,2*sc,0);
   end
else
   puls = impuls;
end

% Generierung des Ausgabesignals
% ==============================
y = conv(puls,nullein([ms*ones(1,ns) symb ms*ones(1,ns)],schritt-1));
y = y(ns*schritt+1:length(y)-ns*schritt);

if nargout>0 & sp==0  break; end

% Darstellung
% ===========
fh1 = fullscreen('Impulsfolge');
plot(1:length(y),y)
yl  = get(gca,'YLim'); dl = yl(2) - yl(1);
axis([1 length(y) yl+0.2*dl*[-1 1]]); axis off
set(gca,'Position',[0 0 1 1]);

if sp==0  break; end

s   = fft(y);
s   = abs(s(1:round(br*length(y)/schritt)));
fh2 = fullscreen('Spektrum');
plot(br*(0:length(s)-1)/length(s),s)
set(fh2,'UserData',{zeros(1,8); 1.2*ones(1,8); {}},'keypressfcn','hervorhebung');
title('Spektrum','Fontsize',fsiz)
xlabel('Frequenz  [Einheit: Schrittfrequenz]','Fontsize',fsiz)