function komplexanimat(s,vis,velocity,blick,mark)
% komplexanimat(s,vis,velocity,blick,mark)
% Animierte Darstellung eines komplexen Signals.
% s       : komplexes Signal
% vis     : binrer Vektor, der die Sichtbarkeit der Linienobjekte
%           festlegt in der Reihenfolge: 
%           kontinuierliches Signal, Abtastpunkte, Strahlen, Zeitachse, 
%           hervorgehobene Zeitpunkte, hervorgehobene Abtastpunkte  
% velocity: Geschwindigkeit der Animation
% blick   : Blickrichtung auf die 3D-Grafik (siehe view)
% mark    : Indexvektor fr hervorzuhebende Abtastpunkte
%
% Whrend der Animation bewirken folgende Tasten etwas:
% Taste  Wirkung
%   s    Abbruch der Ausgabe
%   p    Pause, weiter mit beliebiger Taste
%   +    schneller
%   -    langsamer
%   r    Betrachter 5 Grad nach rechts
%   l    Betrachter 5 Grad nach links
%   h    Betrachter 5 Grad hher
%   t    Betrachter 5 Grad tiefer
%
% Nach Ablauf der Animation kann das Bild mit der Maus gedreht werden.
% Die Sichtbarkeit der Linienobjekte kann dann mit den Tasten 1,2,3,4,5,6
% getoggelt werden. Die Reihenfolge ist wie bei vis.
% Zustzlich gibt es einen Cursor, dessen Sichtbarkeit mit der Taste 0 
% getoggelt wird. Er wird mit den Tasten + und - bewegt.

% Autor:  K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<5  mark = []; end              % keine Hervorhebung
if nargin<4  blick = [25 25]; end        % Blickrichtung
if nargin<3  velocity = 0.5;  end        % Darstellungsgeschwindigkeit
if nargin<2  vis = [1 0 0 0 0 1]; end    % Sichtbarkeit der Linienobjekte
if nargin<1  s = exp(i*2*pi/100*(0:500)); end
if length(vis)<6  vis(6) = 1; end
if length(vis)<5  vis(5) = 0; end
if length(vis)<4  vis(4) = 0; end
if length(vis)<3  vis(3) = 0; end
if length(vis)<2  vis(2) = 1; end
fsz = 12;                                % FontSize fr Beschriftung
lw  = 1.5;                               % LineWidth
col = {'c';'b';'g';0.5*[1 1 1];'k';'r'}; % Color fr Line-Objekte
xanf = 1;
[u,v]= size(s);  if u>v s = s'; end      % 
xend = length(s);

% Signaldarstellung
% =================
h1 = fullscreen('Komplexsignal');
set(h1,'KeyPressFcn','anicont','UserData',0);
ax = [-1,1,-1,1]*max(abs(s));
axis([xanf,xend,ax]);
axis square;
axis manual;
axis on;
xlabel('Zeit','FontSize',fsz);
ylabel('Realteil','FontSize',fsz);
zlabel('Imaginrteil','FontSize',fsz);
set(h1,'CurrentAxes',gca);
l6=line('Marker','.','Color',col{6},'MarkerSize',25,'Visible','off',...
        'EraseMode','none','LineStyle','none','LineWidth',lw);
l2=line('Marker','.','Color',col{2},'MarkerSize',15,'EraseMode','none',...
        'LineStyle','none','LineWidth',lw);
l1=line('Color',col{1},'EraseMode','none','LineWidth',lw,'LineStyle','-');
l3=line('Color',col{3},'EraseMode','none','LineWidth',lw,'LineStyle','-');
l4=line('Color',col{4},'EraseMode','none','LineWidth',lw,'LineStyle','-');
l5=line('Marker','o','Color',col{5},'MarkerSize',5,'EraseMode','none',...
        'LineStyle','-','LineWidth',lw);
l7=line('Color',col{6},'EraseMode','background','LineWidth',lw/2,'LineStyle','-');
view(blick);
k = xanf+1;
stop = 0;
mrk  = min(mark(find(mark>k)));
if length(mark)<1  mrk = 0; else mrkind = min(find(mrk==mark)); end
while (k<xend)&stop==0
   k = k+1;
   switch get(h1,'UserData')
      case  1,  velocity = velocity*2;
      case -1,  velocity = velocity/2;
      case  2,  stop = 1;
   end;
   set(h1,'UserData',0)
   for kk = 1:floor(1000/velocity) sin(kk); end; % Zeitverschwendung
   set(l1,'Color',col{1})
   xd = real(s(k));
   yd = imag(s(k));
   set(l1,'xdata',[k-2,k-1],'ydata',[real(s(k-2)) real(s(k-1))],...
          'zdata',[imag(s(k-2)) imag(s(k-1))],'Color',col{6});
   set(l2,'xdata',k,'ydata',xd,'zdata',yd);
   set(l3,'xdata',[k k],'ydata',[0 xd],'zdata',[0 yd]);
   set(l4,'xdata',[k-1,k],'ydata',[0 0],'zdata',[0 0]);
   set(l5,'xdata',k,'ydata',0,'zdata',0);
   set(l7,'xdata',[k-1,k],'ydata',[real(s(k-1)) xd],'zdata',[imag(s(k-1)) yd]);
   if k==mrk
      set(l6,'xdata',k,'ydata',xd,'zdata',yd);
      mrkind = mrkind + 1;
      if mrkind>length(mark) mrk = 0; else mrk = mark(mrkind); end
      if vis(6) set(l6,'Visible','on'); else set(l6,'Visible','off'); end
   end      
   if vis(1) set(l1,'Visible','on'); else set(l1,'Visible','off'); end
   if vis(2) set(l2,'Visible','on'); else set(l2,'Visible','off'); end
   if vis(3) set(l3,'Visible','on'); else set(l3,'Visible','off'); end
   if vis(4) set(l4,'Visible','on'); else set(l4,'Visible','off'); end
   if vis(5) set(l5,'Visible','on'); else set(l5,'Visible','off'); end
   if vis(6) set(l7,'Visible','on'); else set(l7,'Visible','off'); end
   drawnow;
end;
d  = xanf:k;
xd = real(s(d));
yd = imag(s(d));
zrs= zeros(1,length(d));
delete(l1,l2,l3,l4,l5,l6)
l0= line(1,xd(1),yd(1),'Marker','.','MarkerSize',35,'Visible','off',...
         'MarkerEdgeColor','g','LineStyle','none','UserData',{1;xd;yd});
mrk = mark(find(mark>0&mark<=length(d)));      
l6=line(d(mrk),xd(mrk),yd(mrk),'Marker','.','MarkerEdgeColor',col{6},...
        'MarkerSize',25,'LineStyle','none','LineWidth',lw);
l2=line(d,xd,yd,'Marker','.','Color',col{2},'MarkerSize',15,...
        'LineStyle','none','LineWidth',lw);
l1=line(d,xd,yd,'Color',col{1},'LineWidth',lw);
l3=line([d;d],[zrs;xd],[zrs;yd],'Color',col{3},'LineWidth',lw);
l4=line([xanf,k],[0 0],[0 0],'Color',col{4},'LineWidth',lw,...
        'LineStyle','-');
l5=line(d,zrs,zrs,'Marker','o','Color',col{5},'MarkerSize',5,...
   'LineStyle','-','LineWidth',lw);
set(l7,'Visible','off')
if vis(1) set(l1,'Visible','on'); else set(l1,'Visible','off'); end
if vis(2) set(l2,'Visible','on'); else set(l2,'Visible','off'); end
if vis(3) set(l3,'Visible','on'); else set(l3,'Visible','off'); end
if vis(4) set(l4,'Visible','on'); else set(l4,'Visible','off'); end
if vis(5) set(l5,'Visible','on'); else set(l5,'Visible','off'); end
if vis(6) set(l6,'Visible','on'); else set(l6,'Visible','off'); end
rotate3d on
set(l1,'UserData',10*h1+1)
set(l2,'UserData',10*h1+2)
set(l3,'UserData',10*h1+3)
set(l4,'UserData',10*h1+4)
set(l5,'UserData',10*h1+5)
set(l6,'UserData',10*h1+6)
set(h1,'KeyPressFcn','sichtbarkeit');

