function modspec(mode)
% modspec(mode)
% mode = 0 :  Analoge Modulation mit einer Bitsequenz (Sinc-Impuls)
% mode = 1 :  Analoge Modulation mit einem Sinus (bei QAM zwei Frequenzen)
% mode = 1 :  Analoge Modulation mit einem Zweitonsignal 
%             (bei QAM zwei Zweitonsignale)
% Gezeigt werden Spektren fr 7 Modulationsarten.
% Die einzelnen Spektren knnen durch Drcken der Tasten 1..7
% hervorgehoben werden (Toggeln der Hervorhebung)
% Toggeln zwischen linearer und logarithmischer Skala 
% in x bzw. y durch Drcken der Tasten x bzw. y.

% Autor: Klaus von der Heide, e-mail: v.d.heide@on-line.de

% Konstanten und Defaults
% =======================
if nargin<1  mode = 0; end
f0   = 350;            % Trgerfrequenz
n    = 100;            % Anzahl der Informationsbits
nf   = 16;             % Abtastungen pro Schritt
nn   = 1024;           %
t    = (1:nn)/nn;      % Zeitbereich
nfh  = floor(nf/2);
fsiz = 12;             % FontSize

% Signalerzeugung
% ===============
switch mode
   case 0
      y    = impulsfolge([-1, randb(n-2,[-1,+1]), -1],'Sinc',nf);
      y2   = impulsfolge([-1, randb(n-2,[-1,+1]), -1],'Sinc',nf);
   case 1
      f1   = 20;       % Sinusfrequenz
      f2   = 24;       % Sinusfrequenz
      y    = sin(2*pi*f1*t);
      y2   = sin(2*pi*f2*t); 
   case 2
      f11  = 20;       % Sinusfrequenz
      f21  = 24;       % Sinusfrequenz
      f12  = 14;       % Sinusfrequenz
      f22  =  6;       % Sinusfrequenz
      y    = 0.5*(sin(2*pi*f11*t) + sin(2*pi*f12*t));
      y2   = 0.5*(sin(2*pi*f21*t) + sin(2*pi*f21*t)); 
end
   
% Modulation
% ==========
za = amplmod(f0,y,1);
zf = freqmod(f0,y,0.03);
zp = phasenmod(f0,y,pi/2);
zd = dsbmod(f0,y);
zo = ssbmod(f0,y,0);
zq = qammod(f0,y,y2);
zo = ssbmod(f0,y,+1);
zu = ssbmod(f0,y,-1);

% Spektren
% ========
m  = min([length(za),length(zf),length(zp),length(zq),length(zo),length(zu)]);
if rem(m,2)  m = m - 1; end
mm = m/2;
sa = abs(fft(za(1:m).*hamming(m)'));
sf = abs(fft(zf(1:m).*hamming(m)'));
sp = abs(fft(zp(1:m).*hamming(m)'));
sq = abs(fft(zq(1:m).*hamming(m)'));
sd = abs(fft(zd(1:m).*hamming(m)'));
so = abs(fft(zo(1:m).*hamming(m)'));
su = abs(fft(zu(1:m).*hamming(m)'));
sa = sa(1:mm);
sf = sf(1:mm);
sp = sp(1:mm);
sq = sq(1:mm);
sd = sd(1:mm);
so = so(1:mm);
su = su(1:mm);

% Darstellung
% ===========

fh = fullscreen('Spektren');
f  = (0:mm-1)/mm-f0/mm;
plot(f,sa,'b',f,sf,'g',f,sp,'m',f,sq,'c',f,sd,'k',f,so,'r',f,su,'y')
legend('Amplitudenmodulation','Frequenzmodulation',...
       'Phasenmodulation','Quadraturamplitudenmodulation',...
       'Zweiseitenbandmodulation',...
       'SSB: oberes Seitenband','SSB: unteres Seitenband',2)
title('Spektren der Modulationsarten AM, FM, PM, QAM, DSB, USB, LSB','FontSize',fsiz)
xlabel('Frequenzdifferenz (f - f0)','FontSize',fsiz)
set(gcf,'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}});
set(gcf,'KeyPressFcn','hervorhebung')
axis([-0.32 +0.32 1 1.2*max(sa)])
