function mpsk_noise(m,EbNodB,n)
% mpsk_noise(m,EbNodB,n)
% Signalraumdarstellung von m-PSK im Rauschen von Eb/N0 = EbNodB [dB].
% Optional ist die Anzahl der Punkte n.  Default ist n = 15000.

% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de

% Konstanten und Defaults
% =======================
fsiz = 15;                                    % FontSize
if nargin<3  n = 15000; end
if nargin<2  EbNodB = 6; end
if nargin<1  m = 2; end
g  = 100;                                     % Filtergrad des Hilbertfilters
cf = 1/0.9875;                                % empirisch ermittelter Korrekturfaktor
nn = n + g;

% Hibertfilter
% ============
b = remez(g,[.025 .975],[1 1],'Hilbert');

% Rauschen
% ========
r  = add_awgn(zeros(1,nn),1,EbNodB)/sqrt(log2(m)); % reell
ra = delay(r,floor(g/2)) + i*filter(b,1,r);   % analytisch
ra = cf*ra(g+1:nn);                           % Einschwingen weg und Korrektur

% Signal
% ======
sa = exp(i * (2*pi/m * floor(m*rand(1,n))));  % m-PSK, Symbol-Leistung = 1.0

% Signal + Rauschen
% =================
sr = sa + ra;
mx = max([real(sr),imag(sr)]);

% Darstellung
% ===========
hs = fullscreen('Signalraum');
line(real(sr'),imag(sr'),'LineStyle','none','Marker','.')
line([-mx,0;mx,0],[0,-mx;0,mx],'LineStyle','-','Color','r')
w = 0:pi/90:2*pi;
line(cos(w),sin(w),'LineStyle','-','Color','r') % Einheitskreis
axis([-mx,mx,-mx,mx]); axis square; axis off
title(sprintf('Signalraum:  %2d-PSK  bei  E_b/N_0 = %4.1f dB',...
      m,EbNodB),'FontSize',fsiz)
