function mscriptview(datei)
% mscriptview(datei)
% Dies ist ein Browser fr spezielle MATLAB-Skripte.
% Die Datei datei wird als Text in ein Fenster geladen. 
% In dem Text enthaltene MATLAB-Blcke knnen von dort 
% aus durch Mausklicks oder Tastatur ausgefhrt werden.
%
% Wiederholungen und Rckwrtsschritte im Skript sind mglich.
% Dies erfolgt ber die KeyPressFcn msvkpf bzw. ber die 
% ButtonDownFcn msvbdf sowie ber die durch Klicks auf 
% die Buttons "weiter" und "zurck" angeregten Skripte 
% msvforw und msvback.
%
% datei darf den Pfad enthalten und darf eine Erweiterung
% besitzen. Falls keine Erweiterung angegeben ist, wird
% die Erweiterung *.m angenommen.
%
% Text wird von MATLAB-Code unterschieden durch das 
% Fluchtsymbol % in der ersten Spalte.
% Das Fluchtsymbol %% in Spalten 1 und 2 fhrt zur 
% Darstellung der Zeile in blau/kursiv. Dies wird fr 
% Anweisungen an den Betrachter benutzt.
%
% Zeilen werden in Hintergrundfarbe geschrieben, wenn 
% sie mit einem der folgenden Schlsselwrter beginnen:
%            echo  pause  waitfor
% Diese Zeilen sind dann in MATLAB nicht ausfhrbar.
%
% MATLAB-Blcke werden rot dargestellt und knnen 
% durch Anklicken selektiert (magenta) und durch ein
% zweites Anklicken ausgefhrt werden.
% MATLAB-Blcke werden mit deren Kommentar in ASCII 
% dargestellt. Der eigentliche Script-Text dagegen wird
% mit dem TEX-Interpreter fr MATLAB-Text dargestellt.
%
% Zu allen Fenstern gibt es mit der Taste h jeweils ein 
% Hilfefenster, das die mglichen Interaktionen erlutert.

% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de

% Globale Konstanten
% ==================
global MSVTITLFONT MSVTITLWEIGHT MSVTITLSIZE MSVTITLCOLOR MSVTITLANGLE
global MSVTEXTFONT MSVTEXTWEIGHT MSVTEXTSIZE MSVTEXTCOLOR MSVTEXTANGLE
global MSVKOMTFONT MSVKOMTWEIGHT MSVKOMTSIZE MSVKOMTCOLOR MSVKOMTANGLE
global MSVCODEFONT MSVCODEWEIGHT MSVCODESIZE MSVCODECOLOR MSVCODEANGLE
global MSVFORMFONT MSVFORMWEIGHT MSVFORMSIZE MSVFORMCOLOR MSVFORMANGLE
global MSVMSVFONT MSVMSVWEIGHT MSVMSVSIZE MSVMSVCOLOR MSVMSVANGLE 
global MSVMARKCOLOR MSVSUCHCOLOR MSVSUCHTEXT MSVZEILEN MSVSPALTEN MSVBUSY

% Initialisierung bei erstem Aufruf
% =================================
if isempty(MSVTITLFONT)  msvinit; end

% Suche nach aufrufbaren Toolboxen
% ================================
if nargin<1  
   datei = 'kursmaterial.m'; 
   allp= {};
   pfd = path;
   ix  = [0  findstr(';',pfd)  length(pfd)+1];
   for k=1:length(ix)-1
      pp = suchalle('.msv',pfd(ix(k)+1:ix(k+1)-1),1);
      allp = {allp{:}, pp{:}};
   end
   lap = length(allp);
   for k=1:lap
      if findstr(upper('root.msv'),upper(allp{k}{1}))
         wid = fopen(allp{k}{1},'rt');  % Wurzeldatei
         for kk=k:lap-1  allp{kk} = allp{kk+1}; end
         frewind(wid);
         fid = fopen(datei,'wt+'); 
         while ~feof(wid)
            zle = fgets(wid);
            fprintf(fid,'%s',zle);
         end
         fclose(wid);
         break
      end
   end
   for k=1:lap-1
      aid = fopen(allp{k}{1},'rt');
      frewind(aid);
      zle = fgets(aid);
      fclose(aid);
      fprintf(fid,'%s\n%s\n',zle,'%');
   end
   fclose(fid);
end

% Lokale Konstanten
% =================
ecolor = 'b';                  % Color fr Erluterungen
pcolor = 'w';                  % Color fr pause-Kommandos u..
ss = get(0,'ScreenSize');      % Bildschirmauflsung
if      ss(4)<700   tpos = [1.0  1.0; 1.0  1.0];  % Position des Textfensters
elseif  ss(4)<800   tpos = [1.0  1.3; 1.0  1.3];
elseif  ss(4)<1000  tpos = [1.1  1.4; 1.0  1.4];
else                tpos = [1.3  1.4; 1.0  1.4];
end
if isempty(MSVSUCHTEXT) such = 0; else such = 1; end

% Datei ffnen
% ============
file = reverse(deblank(reverse(deblank(datei)))); % Spaces an Anfang und Ende wegnehmen
if ~ismember('.',file)  file = strcat(file,'.m'); end
allfid = fopen('all');        
fid    = fopen(file,'rt');        % ffnen der Textdatei 
if fid<0  error(sprintf('Die Datei  %s  wurde im Suchpfad nicht gefunden',file)); end
frewind(fid);
if ismember(fid,allfid)
   fhndl = findobj('type','figure','UserData',fid);
   if ~isempty(fhndl)
      figure(findobj('type','figure','UserData',fid))
      break;                      % Fenster war schon da, jetzt vorn
   end
end

[pfad,name,ext,ver] = fileparts(file);

% Fenster konfigurieren
% =====================
tf = fullscreen(name,'w',0,tpos);
set(tf,'KeyPressFcn','msvkpf','UserData',fid,'ButtonDownFcn','msvbdf','CloseRequestFcn','msvclose');
axis([-3  MSVSPALTEN  -MSVZEILEN-1.5  1])  % x-y-Skalierung im Textfenster
set(gca,'Units','normalized','Position',[0 0 1 1])
axis off

% Browser
% =======
zeinr = 1;                      % Zeilenzeiger auf 1 setzen
markerflag = 2;
mzeile = 0;
while ~feof(fid)&zeinr<=MSVZEILEN
   zeile = fgets(fid);
   te = min(findstr('%<',zeile));
   if isempty(te) lz = length(zeile); else lz = te - 1; end
   if iscomment(zeile)==1
      th = text(1,-zeinr,zeile(2:lz),'FontSize',MSVTEXTSIZE,'FontName',MSVTEXTFONT,...
                'FontWeight',MSVTEXTWEIGHT,'FontAngle',MSVTEXTANGLE);
      if markerflag==1  markerflag = 0; end     
   elseif iscomment(zeile)==3
      th = text(1,-zeinr,zeile(3:lz),'FontSize',MSVKOMTSIZE,'FontName',MSVKOMTFONT,...
                'Color',MSVKOMTCOLOR,'FontWeight',MSVKOMTWEIGHT,'FontAngle',MSVKOMTANGLE);
      if markerflag==1  markerflag = 0; end     
   elseif iscomment(zeile)==2
      th = text(1,-zeinr,zeile(1:lz),'FontSize',MSVCODESIZE,'FontName',MSVCODEFONT,...
                'Color',pcolor);
      if markerflag==1  markerflag = 0; end     
   else
      mx = findstr('%MSV',zeile);
      if isempty(mx)
         th = text(1,-zeinr,zeile(1:lz),'FontSize',MSVCODESIZE,'FontName',MSVCODEFONT,...
                   'Color',MSVCODECOLOR,'FontWeight',MSVCODEWEIGHT,'FontAngle',MSVCODEANGLE,...
                   'ButtonDownFcn','msvtextbdf','Interpreter','none');
      else
         th = text(1,-zeinr,zeile(mx+4:lz),'FontSize',MSVMSVSIZE,'FontName',MSVMSVFONT,...
                   'Color',MSVMSVCOLOR,'FontWeight',MSVMSVWEIGHT,'FontAngle',MSVMSVANGLE,...
                   'ButtonDownFcn','msvtextbdf');
      end   
      if markerflag
         text(-1,-zeinr,'|','FontSize',MSVCODESIZE+8,'Color',MSVMARKCOLOR,'FontWeight','bold','ButtonDownFcn','msvmarkbdf'); 
         set(th,'Color',MSVMARKCOLOR,'ButtonDownFcn','msvmarkbdf')   
      end     
      if markerflag==2  
         markerflag = 1; 
         mzeile = zeinr;
      end
   end
   msvsetprop(zeile,th)
   if such  msvsuchmark(th,zeile,zeinr); end
   zeinr = zeinr + 1;
end

set(gca,'UserData',{MSVZEILEN; MSVSPALTEN; [1]; mzeile}); 

if ~feof(fid)
   uhv = uicontrol('Style','pushbutton','units','normalized','Position',[0.95 0.00 0.05 0.05],...
                   'String','weiter','CallBack','msvforw');
   uhz = uicontrol('Style','pushbutton','units','normalized','Position',[0.95 0.95 0.05 0.05],...
                   'String','zurck','CallBack','nooperation','visible','off');
end

set(findobj('Type','text','Parent',gca),'VerticalAlignment','baseline')
