function nqispectrum(v,window)
% nqispectrum(v,window)
% Spektrum von Shannoninterpolation gegenber ungefiltertem PCM.
% v :     Vektor der Niveaus   (Default = [-1,+1])
% window: Halbe Breite des Hanning-Fensters (Default: keines)
% Es wird eine zufllige Sequenz von n Werten aus der Menge v
% erzeugt und das Spektrum fr ungefiltertes PCM sowie fr 
% Shannoninterpolation berechnet und dargestellt.
% Beispiele:  nqispectrum([-1,+1]); nqispectrum(-1.5:+1.5)

% Autor: Klaus von der Heide,  e-mail: v.d.heide@on-line.de

% Defaults
% ========
if nargin<2  window = 1000000; end
if nargin<1  v = [-1 +1]; end
n = 27;                      % Anzahl der Schritte
m = 256;                     % Anzahl der Abtastungen pro Schritt
b = 3;                       % Frequenzereichsfaktor fr Darstellung

% Berechnung
% ==========
x = v([1, ceil(length(v)*rand(1,n-2)),1]); % zuflliges Muster
y = nyquistinterpol(x,m);                  % Shannoninterpolation
fx= abs(fft(nfach(x,m).*hamming(m*n)'))/n; % Spektrum des Binrmusters
fy= abs(fft(y.*hamming(length(y))));       % Spektrum der Interpolation

% Darstellung
% ===========
ix= 1:round(length(y)/b);         % Indexbereich fr 0...Nyquistfreq.
fr= m/(b*n)*(ix-1)/length(ix);    % normierter Frequenzbereich
h3 = fullscreen('Spektrum');
plot(fr,fx(ix),'b',fr,fy(ix),'r') % Darstellung
line(1,0,'Marker','o','MarkerFaceColor','c','MarkerSize',10,'LineStyle','none')
legend('Binrmuster','Shannon-Interpolation','Schrittfrequenz')
title('Spektrum Shannon-Interpolation vs. Rechteck','FontSize',12)
xlabel('Frequenz/Schrittfrequenz','FontSize',12)
set(gca,'XLim',[0,fr(length(fr))])
set(h3,'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}});
set(h3,'keypressfcn','hervorhebung','WindowButtonDownFcn','msvfigbdf','WindowButtonUpFcn','msvfigbuf')
