function  y = nyquistinterpol(x,n,p,k)
% y = nyquistinterpol(x,n,p,k)
% Interpolation des diskreten Signals x nach Shannon
% zu einem Signal aus n Punkten in demselben Intervall.
% Gezeigt werden das interpolierte Signal und die Abtastwerte sowie
% in einem weiteren Bild zustzlich die Teilsignale als sinc-Funktionen,
% eines davon deutlich in dickem Rot hervorgehoben.
% p gibt die Periode im Frequenzbereich an, fr die interpoliert wird.
% p = 0 :  Normalfall;  
% p > 0 ;  p*fs ... (p+0.5)*fs  ist das Band.
% Wird k (optional) als natrliche Zahl angegeben, so wird die sinc-Funktion
% mit (cos(pi*x/k)+1)/2  (+-k Abtastschritte breit) gefenstert.
% Beispiele:  nyquistinterpol(randn(1,15),300);
%             nyquistinterpol(randn(1,15),300,4);

% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de
%
if nargin<3  p = 0; end
if nargin<2  n = 300; end
if nargin<1  x = randn(1,15); end
fs = 15;                             % FontSize fr Beschriftung
m = length(x);
if m > 27  error('Beschrnkung von x auf maximal 27 Elemente!'); end
t  = (1:m)';
ts = linspace(1,m,n)';
yy = sinc(ts(:,ones(size(t))) - t(:,ones(size(ts)))').*cos(2*pi*p*(ts(:,ones(size(t))) - t(:,ones(size(ts)))'));
if nargin > 3
   k1 = 3*k/pi;
   z = ts(:,ones(size(t))) - t(:,ones(size(ts)))';
   z = (zeros(size(z)) + and(z>-k1,z<k1))...
      .*(cos(pi/k*(ts(:,ones(size(t))) - t(:,ones(size(ts)))'))+1)/2;
   yy = yy.*z;
end
y = yy*x';

h1 = fullscreen('Shannon-Interpolation');
plot(t,x,'or',ts,y,'g','LineWidth',2.0)
axis([1,m,1.1*min(y),1.1*max(y)])
if nargin>3 title(sprintf(...
      'Interpolation: sinc-Funktionen mit Hanning-Fenster %g Abtastschritte breit',2*k),...
      'FontSize',15)
   else     title('Shannon-Interpolation mit sinc-Funktionen','FontSize',fs)
end
xlabel('Zeit','FontSize',fs);
ylabel('Signal','FontSize',fs);

h2 = fullscreen('Interpolationsprinzip');
plot(t,x,'or',ts,y,'g','LineWidth',2.0)
axis([1,m,1.1*min(y),1.1*max(y)])
if nargin>3 title(sprintf(...
      'Interpolation: sinc-Funktionen mit Hanning-Fenster %g Abtastschritte breit',2*k),...
      'FontSize',15)
   else     title('Shannon-Interpolation mit sinc-Funktionen','FontSize',fs)
end
xlabel('Zeit','FontSize',fs);
ylabel('Signal','FontSize',fs);
mx = max(abs(x(floor(m/4):ceil(3*m/4))));
for i = 1:m
   tt = t(i)-ts;
   s = x(i)*sinc(tt).*cos(2*pi*p*tt);
   if nargin>3  s = s.*(cos(pi*(t(i)-ts)/k)+1)/2 ...
                    .*(zeros(size(tt)) + and(tt>-k1,tt<k1)); 
   end
   hl(i) = line(ts,s);
end

ix  = find(mx==abs(x));
set(hl(ix(round((length(ix)+1)/2))),'color','r','LineWidth',3.0);

legend('diskrete Inputwerte','interpoliertes Signal','Teilsignale (eines rot)',0)
