function z = phasenmod(f0,x,hub,f1,ph,hubd)
% phasenmod demonstriert die Phasenmodulation.
% Ausgegeben wird das modulierte Signal. Wird die Ausgabe auf 
% eine Variable zugewiesen, so unterbleibt die grafische Darstellung.
% Es wird ein Zeitabschnitt von t = 0...1 gezeigt.
% f0 ist die Trgerfrequenz. Fr die Demonstration ist f0 = 50 gut.
% x ist ein String, der das Signal als Funktion in MATLAB-Syntax mit 
% der Zeitvariablen t angibt. Alternativ kann ein Vektor angegeben 
% werden.
% hub ist der Verstrkungsfaktor fr den Phasenhub. Fr Funktionen x,
% die betragsmssig < 1 sind, ist hub = pi gut.
% f1 ist die zur Dekodierung benutzte Trgerfrequenz und ph dessen 
% Phase. 
% hubd ist der beim Empfnger angenommene Hub
% Defaults  f1 = f0,  ph = 0,  hubd = hub;
% Beispiel:  phasenmod(50,'0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)',2)
%
% Defaults
% ========
if nargin<5   ph = 0;   end
if nargin<3  hub = 2;   end
if nargin<6 hubd = hub; end
if nargin<2   x  = '0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)'; end
if nargin<1   f0 = 50;  end
if nargin<4   f1 = f0;  end                   % Default fr Demodulatortrger
ts    = 1.0;                                  % Lnge des Zeitsegments
fsiz  = 14;
hlcol = 0.7*[1 1 1];
patchcol = 0.8*[1 1 1];
if ischar(x) n = 512; else n = length(x); end
g = 30;                                       % Filtergrad fr Hilbertfilter
mm= 3;
m = g/2+mm;                                   % Einschwingbereich
%
% Signalerzeugung
% ===============
t = ts*(0:n+m-1)/n;                           % Zeitsegment
if ischar(x) s = eval(x); else s = [x,zeros(1,m)]; end     % Signal
z = cos(2*pi*f0*t+hub*s);                     % Phasenmodulation
%
if nargout>0  break; end
%
% Demodulation
% ============
y  = real2analyt(z,g);                        % analytisch
w  = y.*(cos(2*pi*f1*t+ph)-i*sin(2*pi*f1*t+ph));% Transformation ins Basisband
a  = unwrap(angle(w))/hubd;                   % Demodulation 
%
% Wegschneiden des Einschwingbereiches
% ====================================
n = length(t);
t = t(mm+1:n-m+1); s = s(mm+1:n-m+1); z = z(mm+1:n-m+1); a = a(m:n-mm);
%
% Darstellung
% ===========
d  = 0.05;
fh = fullscreen('Phasenmodulation');
axes('Position',[0  2/3  1  1/3-d])
plot(t,s); line([0 1],[0 0],'LineStyle',':','Color',hlcol);
set(gca,'XLim',[0.01,0.99]); axis off
yl = get(gca,'YLim');
if ischar(x) title(x,'FontSize',fsiz); else title('Signal','FontSize',fsiz); end
axes('Position',[0  1/3  1  1/3-d])
patch([t,reverse(t)],[ones(1,length(t)),-ones(1,length(t))],patchcol,'EdgeColor','w')
line([0 1],[ 1  1],'LineStyle',':','Color',hlcol);
line([0 1],[-1 -1],'LineStyle',':','Color',hlcol);
line(t,z)
set(gca,'XLim',[0.01,0.99]); axis off
title('Phasenmodulation','FontSize',fsiz)
axes('Position',[0  0  1  1/3-d])
plot(t,a);
set(gca,'XLim',[0.01,0.99]); axis off
set(gca,'YLim',yl-yl(1)+min(a)-0.1)
title('demoduliertes Signal','FontSize',fsiz)

