function y = pll(x,mitte,prop,int,q,p0)
% y = pll(x,mitte,prop,int,q,p0)
% PLL mit folgenden Parametern:
%  x     :  komplexes (oder reelles) Inputsignal
%  mitte :  Mittenfrequenz der PLL     (0.05)
%  prop  :  proportionale Verstrkung  (0.08)
%  int   :  integrale Verstrkung      (0.05)
%  q     :  Koeffizient des IIR-Filters ersten Grades (0.01)
%  p0    :  Initial-Phase der PLL      (2*pi*rand)
% Ausgegeben wird die komplexe Oszillatorschwingung y.

% Autor:  Klaus von der Heide;  e-mail:  v.d.heide@on-line.de

if nargin<6    p0 = 2*pi*rand; end
if nargin<5     q = 0.000003;  end
if nargin<4   int =   120;     end
if nargin<3  prop = 10000;     end
if nargin<2 mitte = 0.05;      end
if nargin<1    
   t = 1:800;
   x = exp(i*2*pi*0.053*t) + 0.1*randn(size(t));
end

freq  = mitte;
regel = 0;
s     = 0;
for t = 1:length(x)
   y(t)  = exp(-i*(2*pi*freq*t+prop*regel+int*s+p0));
   phase = angle(x(t)*y(t));        % Phasendetektor
   regel = (q*phase + (1-q)*regel); % IIR-Tiefpass ersten Grades
   s     = s + regel;               % Integration
   p(t)  = phase;                   % fr Darstellung
   reg(t)= regel;                   % fr Darstellung
end

if nargout>0 break; end

h1 = fullscreen('Komplex');
plot(real(x-y),imag(x-y)), axis square

h2 = fullscreen('Zeitbereich');
plot(1:length(x),[real(x);real(y);p;5000*reg]), axis([1 500 -2 2])
set(gcf,'keypressfcn','xzoomvis');
title(sprintf('PLL-Einschwingvorgang,  prop = %6.0f,  int = %3.0f,  q = %1.7f',prop,int,q),'FontSize',13) 
legend('Input (Realteil)','Output (Realteil)','Phasendifferenz','Regelspannung')

sound(real(x),8000); pause(2)
sound(real(y),8000)