function x0 = qam14k4(EbNodB,n,r)
% x0 = qam14k4(EbNodB,n,r)
% Signalraumdarstellung von 14k4 im Rauschen von Eb/N0 = EbNodB [dB].
% Die Darstellung unterbleibt, wenn die Ausgabe einer Variablen 
% zugewiesen wird. 
% Die Ausgabe x0 enthlt n komplexe Symbole.
% Falls r=0 (Default) ist x0 rauschfrei, sonst mit Rauschen. 

% Autor: K. von der Heide,  e-mail:  v.d.heide@on-line.de

% Konstanten und Defaults
% =======================
fsiz = 15;                                    % FontSize
if nargin<3  r = 0;       end
if nargin<2  n = 15000;   end
if nargin<1  EbNodB = 20; end

% Symbole
% =======
%a = sqrt(64/672);                             % Gitterkonstante fr Es = 1
a = sqrt(6*64/672);                           % Gitterkonstante fr Eb = 1
%a = 1/3.5;                                    % Gitterkonstante -1<=x0<=+1
sig = [];
for k = 1:8
   sig = [sig, a*(k - 4.5 + i*(-7:2:+7)/2)];
end

% Rauschen
% ========
ra  = add_awgn(zeros(1,n),1,EbNodB-3)...      % reell
      + i*add_awgn(zeros(1,n),1,EbNodB-3);    % imaginr

% Signal
% ======
sa = sig(ceil(64*rand(1,n)));                 % Signal

% Signal + Rauschen
% =================
sr = sa + ra;
mx = max([real(sr),imag(sr)]);

if r  x0 = sr; else x0 = sa; end
if nargout  break; end

% Darstellung
% ===========
hs = fullscreen('64-QAM');
line(real(sr'),imag(sr'),'LineStyle','none','Marker','.')
line([-mx,0;mx,0],[0,-mx;0,mx],'LineStyle','-','Color','r')
axis([-mx,mx,-mx,mx]); axis square; axis off
title(sprintf('Signalraum:  64-QAM  Eb/No = %4.1f dB',...
      EbNodB),'FontSize',fsiz)
