function z = qammod(f0,x1,x2,f1,ph)
% z = qammod(f0,x1,x2,f1,ph)
% Demonstriert die Quadraturamplitudenmodulation.
% Ausgegeben wird das modulierte Signal. Wird die Ausgabe auf 
% eine Variable zugewiesen, so unterbleibt die grafische Darstellung.
% Es wird ein Zeitabschnitt von t = 0...1 gezeigt.
% f0 ist die Trgerfrequenz. Fr die Demonstration ist f0 = 50 gut.
% x1 und x2 sind Strings, die die Signale als Funktion in MATLAB-Syntax 
% mit der Zeitvariablen t angeben. Alternativ knnen Vektoren angegeben 
% werden.
% Demoduliert wird mit der Trgerfrequenz f1 und dessen Phase ph.
% Beispiel:  
% qammod(50,'0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)','cos(2*pi*7*t).*(1-cos(2*pi*1*t))')
%
% Defaults
% ========
if nargin<5 ph = 0; end
if nargin<3 x2 = 'cos(2*pi*7*t).*(1-cos(2*pi*1*t))'; end
if nargin<2 x1 = '0.5*sin(2*pi*3*t)+0.3*cos(2*pi*5*t)'; end
if nargin<1 f0 = 50; end
if nargin<4 f1 = f0; end                      % Default fr Demodulatortrger
patchcol = 0.8*[1 1 1];
hlcol = 0.7*[1 1 1];
fsiz  = 14;
ts = 1.0;                                     % Lnge des Zeitsegments
if ischar(x1) 
   fs = 1000;                                 % Abtastrate
   n = round(fs*ts); 
else 
   n = length(x1); 
   fs= n/ts;   
end
%
% Signalerzeugung
% ===============
t  = ts*(0:(n-1))/n;                          % Zeitsegment
if ischar(x1) s1 = eval(x1); else s1 = x1; end% Signal 1
if ischar(x2) s2 = eval(x2); else s2 = x2; end% Signal 2
if length(s1)~=length(s2) error('Vektoren x1 und x2 mssen gleich lang sein.'); end
z  = s1.*cos(2*pi*f0*t) + s2.*sin(2*pi*f0*t); % Modulation
%
if nargout>0  break; end
%
% Demodulation
% ============
pi2= fs/f1;
p4n= ts*pi2/4/n;
wt = ts*(0:pi2:n-1)/n + ph/(2*pi*f0);
wk = 1:length(wt);
w1 = flach([interp1(t,z,wt); -interp1(t,z,wt+2*p4n)]');
w2 = flach([interp1(t,z,wt+p4n); -interp1(t,z,wt+3*p4n)]');
k  = length(w1);
w1t= ts*(0:k-1)/k;
w2t= w1t+p4n;
%
% Darstellung
% ===========
d  = 0.05;
fh = fullscreen('QAM');
axes('Position',[0  4/5-d/2  1  1/5-d])
plot(t,s1); line([0 ts],[0 0],'LineStyle',':','Color',hlcol);
set(gca,'XLim',[0.01,ts-0.01]); axis off
if ischar(x1) title(x1,'FontSize',fsiz); else title('Signal 1','FontSize',fsiz); end
axes('Position',[0  3/5  1  1/5-d])
plot(t,s2); line([0 ts],[0 0],'LineStyle',':','Color',hlcol);
set(gca,'XLim',[0.01,ts-0.01]); axis off
if ischar(x2) title(x2,'FontSize',fsiz); else title('Signal 2','FontSize',fsiz); end
axes('Position',[0  2/5  1  1/5-d])
amp = sqrt(s1.^2 + s2.^2);
patch([t,reverse(t)],[amp,-reverse(amp)],patchcol,'EdgeColor','w'); 
line(t,z)
set(gca,'XLim',[0.01,ts-0.01]); axis off
title('Quadraturamplitudenmodulation (QAM)','FontSize',fsiz)
axes('Position',[0  1/5  1  1/5-d])
plot(w1t,w1); line([0 ts],[0 0],'LineStyle',':','Color',hlcol);
set(gca,'XLim',[0.01,ts-0.01]); axis off
title('demoduliertes Signal 1','FontSize',fsiz)
axes('Position',[0  d/2  1  1/5-d])
plot(w2t,w2); line([0 ts],[0 0],'LineStyle',':','Color',hlcol);
set(gca,'XLim',[0.01,ts-0.01]); axis off
title('demoduliertes Signal 2','FontSize',fsiz)

