function y = raisedcosine(x,n)
% y = raisedcosine(x,n)
% Die diskreten Werte des Vektors x werden mit Cosinus-
% Verlauf untereinander verbunden. Die Abtastrate wird 
% dabei um den Faktor n erhht.
% 
% Wenn die Ausgabe nicht auf eine Variable zugewiesen 
% wird, gibt es eine grafische Darstellung.

% Autor: Klaus von der Heide, e-mail: v.d.heide@on-line.de

% Defaults
% ========
if nargin<2  n = 50; end               % Default fr n
if nargin<1  x = 2*randb(10) - 1, end  % Default fr x

costab = cos(pi/n*(0:n-1));            % cos-Tabelle

% Berechnung
% ==========
y = [];
for k=1:length(x)-1
   y = [y, (x(k)+x(k+1))/2 + (x(k)-x(k+1))/2*costab];
end

if nargout>0  break; end

% Darstellung
% ===========
fig1 = fullscreen('Raised Cosine');
plot((0:length(y)-1)/n,y)
line((1:length(x))-1,x,'LineStyle','none','Marker','o',...
     'MarkerFaceColor','r')
miny = min(y);  maxy = max(y);  b = (maxy - miny)/10;
axis([0, length(y)/n, miny-b, maxy+b])
title('Raised Cosine','FontSize',13)
