function rcspectrum(v)
% rcspectrum(v)
% Spektrum von raised cosine gegenber ungefiltertem PCM.
% v :  Vektor der Niveaus   (Default = [-1,+1])
% Es wird eine zufllige Sequenz von 256 Werten aus der Menge v
% erzeugt und das Spektrum fr ungefiltertes PCM sowie fr 
% Raised-Cosine berechnet und dargestellt.
% Beispiele:  rcspectrum([-1,+1]);  rcspectrum(-1.5:+1.5)

% Autor: Klaus von der Heide,  e-mail: v.d.heide@on-line.de

% Defaults
% ========
if nargin<1  v = [-1 +1]; end
n = 256;                     % Anzahl der Schritte
m = 6;                       % Anzahl der Abtastungen pro Schritt
fsiz = 13;                   % FontSize

% Berechnung
% ==========
x = v([1, ceil(length(v)*rand(1,n-2)),1]); % zuflliges Muster
y = raisedcosine(x,m);       % verbinden mit raised cosine
fx= abs(fft(nfach(x,m)));    % Spektrum des Binrmusters
fy= abs(fft(y));             % Spektrum des raised cosine

% Darstellung
% ===========
ix = 1:length(y)/2;          % Indexbereich fr 0...Nyquistfreq.
fr = (m/2)*(ix-1)/length(ix);      % normierter Frequenzbereich
fig1 = fullscreen('Spectrum Raised Cosine');
plot(fr,fx(ix),'b',fr,fy(ix),'r')  % Darstellung
line(1,0,'Marker','o','MarkerFaceColor','c','MarkerSize',10,'LineStyle','none')
legend('Binrmuster','Raised Cosine','Schrittfrequenz')
set(fig1,'NumberTitle','off','MenuBar','none','Name','Spektrum','keypressfcn','hervorhebung',...
         'WindowButtonDownFcn','msvfigbdf','WindowButtonUpFcn','msvfigbuf')
set(fig1,'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}});
title('Spektrum Raised-Cosine vs. Rechteck','FontSize',fsiz)
xlabel('Frequenz/Schrittfrequenz','FontSize',fsiz-1)
mx = max(fy);
set(gca,'ylim',1.1*[1e-5 1]*mx)
