function x = sampling(tmax,fs,f,phi)
% x = sampling(tmax,fs,f,phi)
% Abtastung von  cos(2*pi*f*t+phi)  im Zeitbereich  t = 0..tmax mit der 
% Abtastrate fs  und Darstellung der Aliasfrequenzen bis 2*fs+f.

% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<4  phi = 0.6; end;
if nargin<3  f = 1.4; end;
if nargin<2  fs = 5.0; end;
if nargin<1  tmax = 1; end;
%
% Zeitbereich
% ===========
t = tmax*(0:799)/800;
n = floor(tmax*fs);
ts= (0:n)/fs;
ys= cos(2*pi*f*ts+phi);
%
% Darstellung
% ===========
h = fullscreen('Alias');
line(t,zeros(size(t)),'Color',0.7*[1 1 1]);
line(t,cos(2*pi*f*t+phi));
for i = 0:n  line([ts(i+1),ts(i+1)],[0,cos(2*pi*f*ts(i+1)+phi)],'Color','r','LineWidth',2.5); end
axis([0 tmax -1.2 1.2])
line(ts,ys,'Marker','o','Color','r','LineStyle','none','MarkerSize',5,'LineWidth',3);
pause(2)
line(t,cos(2*pi*(fs-f)*t-phi),'Color','g');
pause(2)
line(t,cos(2*pi*(fs+f)*t+phi),'Color','g');
pause(2)
line(t,cos(2*pi*(2*fs-f)*t-phi),'Color','g');
pause(2)
line(t,cos(2*pi*(2*fs+f)*t+phi),'Color','g','Color','g');
delete(h)

h = fullscreen('Alias');
line(t,cos(2*pi*f*t+phi));
axis([0 tmax -1.2 1.2])
ys= cos(2*pi*f*ts+phi);
line(t,cos(2*pi*(fs-f)*t-phi),'Color','g');
line(t,cos(2*pi*(fs+f)*t+phi),'Color','g');
line(t,cos(2*pi*(2*fs-f)*t-phi),'Color','g');
line(t,cos(2*pi*(2*fs+f)*t+phi),'Color','g','Color','g');
line(ts,ys,'Marker','o','Color','r','LineStyle','none','MarkerSize',5,'LineWidth',3);
line(t,zeros(size(t)),'Color',0.7*[1 1 1]);
for i = 0:n  line([ts(i+1),ts(i+1)],[0,cos(2*pi*f*ts(i+1)+phi)],'Color','r','LineWidth',2.5); end
x = ys;
set(h,'KeyPressFcn','hervorhebung')
set(h,'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}});
