function [x0,y0] = sinprec(m,methode)
% [x0,y0] = sinprec(m,methode)
% sinprec plottet den Fehler der Realisierung der Sinusfunktion
% mit einer Sin/Cos-Tabelle der Lnge m fr
% methode = 1 :  Tabelle ohne Interpolation
% methode = 2 :  Lineare Interpolation 
% methode = 3 :  Taylor-Entwicklung dritten Grades an der nchsten 
%                tieferen Sttzstelle.

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de
%
if nargin<1  m = 16; end
if nargin<2  methode = 3; end
k = 16384;
x = 1/k*(0:k-1);
x0= floor(m*x)/m;
t = 2*pi*(x-x0);
s = sin(2*pi*x0);
c = cos(2*pi*x0);
ss= sin(2*pi*(x0+1/m));
si= sin(2*pi*x);
switch methode
   case 1        % direkter Tabellenwert
      y = s;
      titel = sprintf('Tabelle ohne Interpolation, Sinustabelle der Lnge %4.0f',m);
   case 2        % lineare Interpolation
      y = s + t.*(ss - s)*m/(2*pi);
      titel = sprintf('Lineare Interpolation, Sinustabelle der Lnge %4.0f',m);
   case 3        % Taylorentwicklung
      y = s + t.*(c - t.*(s/2 + t.*(c/6)));
      titel = sprintf('Taylorentwicklung dritten Grades, Sinustabelle der Lnge %4.0f',m);
   otherwise error('Methode falsch');
end;
z = y - si;
h = fullscreen('SIN');
set(h,'Name','SIN');
plot(2*x,z);
title(titel,'Fontsize',14)
xlabel('\alpha / \pi','FontSize',18); 
ylabel('Fehler','FontSize',14);
