function br = specrot(b,phi);
% br = specrot(b,phi)
% Spektrale Rotation eines Filterfrequenzganges.
% b   :  FIR-Filterkoeffizienten
% phi :  Drehwinkel (2*pi ist eine volle Rotation)
%        Ist phi ein Vektor, so wird fr alle Komponenten gerechnet.
% In der Matrix br werden die fr alle Drehungen ermittelten 
% Koeffizienten als Zeilen ausgegeben.
% Wird  specrot  ohne Ausgabe aufgerufen, so werden die Frequenzgnge
% geplottet.
% Defaultwerte sind:  b=fir1(60,0.1);  phi=[pi/4,pi/4+0.05,pi/4+0.1]

% Autor: K. v. d. Heide, e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<1    b = fir1(60,0.1); end;
if nargin<2  phi = [pi/4,pi/4+0.05,pi/4+0.1]; end;

% Konstanten
% ==========
fsiz = 13;                          % FontSize
g = length(b)-1;                    % Filtergrad
t = (0:g);                          % Zeitbereich
bb{1} = b;                          % bb wird geplottet

legende(1,:) = sprintf('Originalfrequenzgang               ');
for k = 1:length(phi)
   br(k,:) = b.*exp(i*phi(k)*t);    % Drehung phi(k)
   bb{k+1} = br(k,:);
   legende(k+1,:) = sprintf('Frequenzgang verschoben um %5.2f*pi',phi(k)/pi);
end
if nargout<1                        % Plot nur, wenn keine Ausgabe
   figh = fullscreen('Spektrale Rotation');
   set(figh,'KeyPressFcn','hervorhebung')
   set(figh,'UserData',{zeros(1,8); 1.2*ones(1,8); {'b';'g';'m';'c'}});
   filterplot(bb');
   title('Spektrale Rotation','FontSize',fsiz);
   legend(legende)
end