function [rxbits,fehler] = startstop(txschritt,rxschritt,txbits)
% [rxbits,fehler] = startstop(txschritt,rxschritt,txbits)
% Simulation der Datenbertragung mit Start/Stopp-Synchronisation.
% txschritt :  Schrittlnge fr ein Bit beim Sender (reelle Zahl >= 1).
% rxschritt :  Schrittlnge fr ein Bit beim Empfnger (reelle Zahl >= 1).
% txbits    :  zu bertragende Bits (Binrvektor der Lnge m*8).
% rxbits    :  empfangene Bits (sie sollten identisch zu txbits sein)
% fehler    :  Summe der Bitfehler
% Alle Parameter sind optional. Die Defaults sind:
% txschritt und rxschritt : 100  (sinnvolle Werte 4...400)
% txbits    :  16 zufllige Bits

% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de
%
% Defaults
% ========
if nargin<3  txbits = randb(16); end % Default txbits
if nargin<2  rxschritt = 100; end    % Default rxschritt
if nargin<1  txschritt = 100; end    % Default txschritt
n = length(txbits);
if rem(n,8) error('rs232: die Lnge von txbits muss 8*m sein'); end
if screen==1 pos = [1 430 800 150]; else pos = [1 586 1024 164]; end
m = n/8;

% Sender
% ======
sequenz = ones(1,round(10*rand+3));  % zuflliger Vorlauf
lv = length(sequenz);                % Lnge des Vorlaufs
for k=0:m-1
   sequenz = [sequenz 0 txbits(8*k+1:8*k+8) 1 1]; % Startbit, Byte, 2 Stoppbits
end
sequenz = [sequenz ones(1,13-lv)];   % Auslauf
if (txschritt*(length(sequenz) - 1) + 1)>16384
   error('txschritt bzw. Anzahl der Bits zu gross fr Studentenversion'); 
end
zeiger = 1;
for k=1:length(sequenz)
   nzeiger = round(k*txschritt)+1;
   signal(zeiger:nzeiger-1) = sequenz(k);
   zeiger  = nzeiger;
end
lsig    = length(signal);
signal  = [signal,ones(1,15384-lsig)];

% Empfnger
% =========
bereich= 1:length(signal);           % gesamter Zeitbereich
nflanke= delay(signal,1) - signal;   % fallende Flanken sind hier +1
zeiger = 1;                          % Zeiger: noch lesen
abtast = [];                         % Abtastzeitpunkte
startf = [];                         % fallende Flanke des Startbits
while ~all(signal(zeiger:length(signal)))
   minm   = min(find((bereich>=zeiger).*(nflanke==1)));
   if isempty(minm)  break; end
   startf = [startf,minm];
   tast   = minm + round(0.5*rxschritt + cumsum(rxschritt*ones(1,8)));
   abtast = [abtast, tast];          % Abtastpunkte
   zeiger = max(tast) + round(1.5*rxschritt); % Zeitzeiger   
end
abtast = round(abtast);              % runden auf ganze Abtastpunkte
while (abtast(length(abtast))>length(signal))&length(abtast)>1
   abtast = abtast(1:length(abtast)-1);
end
if abtast(1)>length(signal)  abtast(1) = length(signal); end 
   
rxbits = signal(abtast);             % Abtastung der Bits

% Auswertung
% ==========
if length(rxbits)==length(txbits)
   fehler = sum(rxbits~=txbits);     % Anzahl der Bitfehler
else fehler = -1;                    % Anzahl der Bitfehler nicht angebbar
end

% Darstellung
% ===========
fh = fullscreen('RS-232','w',2,[0 1 0.75 1]);
axes('Position',[0  0.1  1  0.8])
plot(1:lsig,signal(1:lsig))
line([0 lsig],[0 0],'LineStyle',':','Color',0.7*[1 1 1])
lh = line(abtast,signal(abtast));
set(lh,'LineStyle','none','Marker','*','MarkerEdgeColor','r')
line([startf;startf],(ones(length(startf),1)*[0,1])','Color','b','LineWidth',2.5)
set(gca,'XLim',[0,lsig],'YLim',[-0.5,1.5])
text(50,-0.23,sprintf('txschritt =%4.1f   rxschritt =%4.1f',txschritt,rxschritt),...
      'FontSize',11)
