function  [pu,pm,dly] = unwrapf(p,fu)
% [pu,pm,dly] = unwrapf(p,fu)
% Alternative zu unwrap.
% Es wird eine Filterung der Phasen p mit einem Tiefpass 
% der Grenzfrequenz fu (relativ zur Abtastfrequenz) vorgenommen.
% Im Gegensatz zu unwrap ist pu um dly verzgert gegen p.
%
% Verfahren:
% p1 = p mod 2*pi;  und versetzt um pi:
% p2 = (p + pi) mod 2*pi
% p1f = TP(p1);  p2f = TP(p2); wo TP Tiefpass bedeutet.
% Die lokale Standardabweichung des Phasenrauschens 
% ist am grssten bei den Phasensprngen. Beide Kanle 
% sind um pi gegeneinander versetzt, so dass jeweils 
% der Bereich ohne Sprung mit der kleinsten Standardabweichung 
% gewhlt werden kann.
%
% Wird keine Zuweisung der Resultate vorgenommen, so gibt es 
% eine das Verfahren erluternde Graphik.

% Autor:  K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Default
% =======
if nargin<2  fu = 0.01; end

% Filterentwurf
% =============
[b,a] = ellip(2,0.5,60,fu);
dly = round(mean(grpdelay(b,a,(0:10)/10*fu,1)));

dlp = delay(p,dly);

% Zwei parallele Kanle um pi versetzt
% ====================================
p1 = mod(p,2*pi) - pi;
p2 = mod(p+pi,2*pi) - pi;

p1f = filter(b,a,p1);
p2f = filter(b,a,p2);

d1f = filter(b,a,(p1 - delay(p1f,-dly)).^2);
d2f = filter(b,a,(p2 - delay(p2f,-dly)).^2);

s12 = d1f>d2f;

dd  = [0 diff(s12)];

pp  = p1f.*(1-s12) + p2f.*s12;

pm  = pp + pi*cumsum(dd.*sign(p1f-p2f));
dpp = pi*round((mean(mod(dlp-pm+pi/2,2*pi))-pi/2)/pi);
pm  = pm - dpp;

dp  = dlp - pm;
dpp = mod(dp+pi,2*pi)-pi;
pu  = pm + dpp;

if nargout>0  break; end

% Graphik
% =======
fh1 = fullscreen('Test','w',3,[2 1; 1 1]);
plot([dpp;p1f;p2f;d1f;d2f;s12;pp]')
legend('Rest','p1f','p2f','d1f','d2f','s12','pp')

dd = round(2.5*dly);
p  = p(dd:end);
pm = pm(dd:end);
pu = pu(dd:end);

fh2 = fullscreen('Test','w',0,[2 2; 2 1]);
plot([pu; pm]')
legend('pu','pm')

fh3 = fullscreen('Test','w',0,[2 2; 2 2]);
a1  = 1.05;
x1  = a1*exp(-i*(delay(p,dly)-pm));
line(real(x1),imag(x1),'Marker','.','Color','b','MarkerSize',12,'LineStyle','none')
a2  = 0.95;
x2  = a2*exp(-i*p);
line(real(x2),imag(x2),'Marker','.','Color','g','MarkerSize',12,'LineStyle','none')
a  = 1.2;
line(a*[-1 0; +1 0],a*[0 -1; 0 +1],'Color',0.7*[1 1 1])
line(1,0,'Marker','.','MarkerSize',20,'Color','r')
axis(a*[-1 +1 -1 +1]); axis square; axis off
%'Testpunkt'

