function x0 = v27bis(snr,n)
% v27bis(snr,n)
% Signalraumdarstellung von CCITT V.27bis im Rauschen von snr.
% Es werden die zwei bertragungsraten 4k8 und 2k4 auf zwei 
% Bildern dargestellt.
% Die Darstellung unterbleibt, wenn die Ausgabe einer Variablen 
% zugewiesen wird. Die Ausgabe x0 enthlt n komplexe Symbole 
% den Fall 4k8 ohne Rauschen.

% Autor: K. von der Heide,  e-mail:  v.d.heide@on-line.de

% Konstanten und Defaults
% =======================
fsiz = 15;                                    % FontSize
if nargin<2    n = 15000; end
if nargin<1  snr = 15;    end

% Symbole in CCITT V.27bis 4k8
% ============================
sig = exp(i*pi*(0:45:359)/180)';

% Signal
% ======
sa = sig(ceil(length(sig)*rand(1,n)))';       % Signal

x0 = sa;
if nargout  break; end

% Rauschen
% ========
ra  = add_awgn(zeros(1,n),1,snr)...           % reell
      + i*add_awgn(zeros(1,n),1,snr);         % imaginr

% Signal + Rauschen
% =================
sr = sa + ra;
mx = max([real(sr),imag(sr)]);

% Darstellung 4k8
% ===============
h1 = fullscreen('V.27bis')
subplot(1,2,1)
line(real(sr'),imag(sr'),'LineStyle','none','Marker','.')
line([-mx,0;mx,0],[0,-mx;0,mx],'LineStyle','-','Color','r')
axis([-mx,mx,-mx,mx]); axis square; axis off
title(sprintf('V.27bis 4k8  SNR = %4.1f dB',snr),'FontSize',fsiz)

% Symbole in CCITT V.27bis 2k4
% ============================
nn = round(n/2);                     
sig = exp(i*pi*(0:90:359)/180)';

% Signal
% ======
sa = sig(ceil(length(sig)*rand(1,nn)))';      % Signal

% Rauschen
% ========
ra  = add_awgn(zeros(1,nn),1,snr)...          % reell
      + i*add_awgn(zeros(1,nn),1,snr);        % imaginr

% Signal + Rauschen
% =================
sr = sa + ra;
mx = max([real(sr),imag(sr)]);

% Darstellung
% ===========
subplot(1,2,2)
line(real(sr'),imag(sr'),'LineStyle','none','Marker','.')
line([-mx,0;mx,0],[0,-mx;0,mx],'LineStyle','-','Color','r')
axis([-mx,mx,-mx,mx]); axis square; axis off
title(sprintf('V.27bis 2k4  SNR = %4.1f dB',snr),'FontSize',fsiz)
