function x0 = v29(snr,n,r)
% v29(snr,n,r)
% Signalraumdarstellung von CCITT V.29 (Fax)im Rauschen mt snr. 
% Das Signal-Rauschverhltnis snr bezieht sich auf die mittlere 
% Signalleistung.
% Es werden die drei bertragungsraten 9k6, 7k2 und 4k8 auf 
% drei Bildern dargestellt.
% ASK/PSK auf f0 = 1700 Hz unidirektional mit 2400 Baud.
% Die Darstellung unterbleibt, wenn die Ausgabe einer Variablen 
% zugewiesen wird. 
% Die Ausgabe x0 enthlt n komplexe Symbole fr den Fall 9k6.
% Falls r=0 (Default) ist x0 rauschfrei, sonst mit Rauschen. 

% Autor: K. von der Heide,  e-mail:  v.d.heide@on-line.de

% Konstanten und Defaults
% =======================
fsiz = 14;                                    % FontSize
if nargin<3    r = 0;     end
if nargin<2    n = 15000; end
if nargin<1  snr = 15;    end

% Symbole in CCITT V.29 9k6
% =========================
a = sqrt(4/54);
sig = a*[ 1+1*i; -1+1*i; -1-1*i;  1-1*i;
          3+0*i;  0+3*i; -3+0*i;  0-3*i;
          3+3*i; -3+3*i; -3-3*i;  3-3*i;
          5+0*i;  0+5*i; -5+0*i;  0-5*i];

% Signal
% ======
sa = sig(ceil(length(sig)*rand(1,n)))';       % Signal

% Rauschen
% ========
ra  = add_awgn(zeros(1,n),1,snr)...           % reell
      + i*add_awgn(zeros(1,n),1,snr);         % imaginr

% Signal + Rauschen
% =================
sr = sa + ra;
mx = max([real(sr),imag(sr)]);

if r  x0 = sr; else x0 = sa; end
if nargout  break; end

% Darstellung 7k2
% ===============
h1 = fullscreen('V.29 9k6','w',0,[1/3 1 0 1]);
line(real(sr'),imag(sr'),'LineStyle','none','Marker','.')
line([-mx,0;mx,0],[0,-mx;0,mx],'LineStyle','-','Color','r')
xlabel('Bild 1 von 3')
axis([-mx,mx,-mx,mx]); axis square; axis off
title(sprintf('Signalraum:  CCITT V.29 (Fax) 9k6  SNR = %4.1f dB',...
      snr),'FontSize',fsiz)

% Symbole in CCITT V.29 7k2
% =========================
nn = round(n/2);                     
a = sqrt(4/54);
sig = a*[sqrt(3)*[1+1*i; -1+1*i; -1-1*i;  1-1*i;]
          5+0*i;  0+5*i; -5+0*i;  0-5*i];

% Signal
% ======
sa = sig(ceil(length(sig)*rand(1,nn)))';      % Signal

% Rauschen
% ========
ra  = add_awgn(zeros(1,nn),1,snr)...     % reell
      + i*add_awgn(zeros(1,nn),1,snr);   % imaginr

% Signal + Rauschen
% =================
sr = sa + ra;
mx = max([real(sr),imag(sr)]);

% Darstellung
% ===========
h2 = fullscreen('V.29 7k2','w',0,[0 1/3 1/2 1]); 
line(real(sr'),imag(sr'),'LineStyle','none','Marker','.')
line([-mx,0;mx,0],[0,-mx;0,mx],'LineStyle','-','Color','r')
axis([-mx,mx,-mx,mx]); axis square; axis off
title(sprintf('V.29 (Fax) 7k2  SNR = %4.1f dB',...
      snr),'FontSize',fsiz)
xlabel('Bild 2 von 3')

% Symbole in CCITT V.29 4k8
% =========================
nn = round(n/4);
a = sqrt(4/54);
sig = a*[5+0*i;  0+5*i; -5+0*i;  0-5*i];

% Signal
% ======
sa = sig(ceil(length(sig)*rand(1,nn)))';      % Signal

% Rauschen
% ========
ra  = add_awgn(zeros(1,nn),1,snr)...     % reell
      + i*add_awgn(zeros(1,nn),1,snr);   % imaginr

% Signal + Rauschen
% =================
sr = sa + ra;
mx = max([real(sr),imag(sr)]);

% Darstellung
% ===========
h3 = fullscreen('V.29 4k8','w',0,[0 1/3 0 1/2]); 
line(real(sr'),imag(sr'),'LineStyle','none','Marker','.')
line([-mx,0;mx,0],[0,-mx;0,mx],'LineStyle','-','Color','r')
axis([-mx,mx,-mx,mx]); axis square; axis off
title(sprintf('V.29 (Fax) 4k8  SNR = %4.1f dB',...
      snr),'FontSize',fsiz)
xlabel('Bild 3 von 3')
figure(h1)
